@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -130,7 +130,7 @@ A convoluted example:
     my $groups = RT::Groups->new(RT->SystemUser);
     $groups->LimitToUserDefinedGroups();
     $groups->Limit(FIELD => "Name", OPERATOR => "=", VALUE => $name, CASESENSITIVE => 0);
-    $groups->WithMember($TransactionObj->CreatorObj->Id);
+    $groups->WithMember(PrincipalId => $TransactionObj->CreatorObj->Id);
 
     my $groupid = $groups->First->Id;
 
@@ -246,6 +246,10 @@ A complete list of acceptable fields:
 
        SkipCreate        => 0/1, if true, skip this create ticket block
 
+       CustomRole-<id#> => custom role email address
+       CR-name          => custom role email address
+       CustomRole-name  => custom role email address
+
 Fields marked with an C<*> are required.
 
 Fields marked with a C<+> may have multiple values, simply
@@ -460,7 +464,6 @@ sub UpdateByTemplate {
             AttributesRef => \@attribs,
             ARGSRef       => $ticketargs
         );
-
         if ( $ticketargs->{'Owner'} ) {
             ($id, $msg) = $T::Tickets{$template_id}->SetOwner($ticketargs->{'Owner'}, "Force");
             push @results, $msg unless $msg eq $self->loc("That user already owns that ticket");
@@ -701,6 +704,7 @@ sub ParseLines {
                 }
                 if (
                     ($tag =~ /^(requestor|cc|admincc)(group)?$/i
+                        or $tag =~ /^(customrole|cr)-?(.+)$/i
                         or grep {lc $_ eq $tag} keys %RT::Link::TYPEMAP)
                     and $args{$tag} =~ /,/
                 ) {
@@ -794,6 +798,11 @@ sub ParseLines {
             );
             next unless $cf->id;
             $ticketargs{ "CustomField-" . $cf->id } = $args{$tag};
+        } elsif ($orig_tag =~ /^(?:customrole|cr)-?(.+)$/i) {
+            my $cr = RT::CustomRole->new( $self->CurrentUser );
+            $cr->Load($1);
+            next unless $cr->id;
+            $ticketargs{ "RT::CustomRole-" . $cr->id } = $args{$tag};
         } elsif ($orig_tag) {
             my $cf = RT::CustomField->new( $self->CurrentUser );
             $cf->LoadByName(
@@ -802,9 +811,15 @@ sub ParseLines {
                 ObjectId      => $ticketargs{Queue},
                 IncludeGlobal => 1,
             );
-            next unless $cf->id;
-            $ticketargs{ "CustomField-" . $cf->id } = $args{$tag};
+            if ($cf->id) {
+                $ticketargs{ "CustomField-" . $cf->id } = $args{$tag};
+                next;
+            }
 
+            my $cr = RT::CustomRole->new( $self->CurrentUser );
+            $cr->Load($orig_tag);
+            next unless $cr->id;
+            $ticketargs{ "RT::CustomRole-" . $cr->id } = $args{$tag};
         }
     }
 
@@ -1087,9 +1102,11 @@ sub UpdateWatchers {
 
     my @results;
 
-    foreach my $type (qw(Requestor Cc AdminCc)) {
-        my $method  = $type . 'Addresses';
-        my $oldaddr = $ticket->$method;
+    my @types = grep /^RT::CustomRole-\d+$/, keys %$args;
+    @types = (@types, qw(Requestor Cc AdminCc));
+
+    foreach my $type (@types) {
+        my $oldaddr = $ticket->RoleAddresses($type);
 
         # Skip unless we have a defined field
         next unless defined $args->{$type};
@@ -1126,7 +1143,6 @@ sub UpdateWatchers {
                 Type  => $type,
                 Email => $_
             );
-
             push @results,
                 $ticket->loc( "Ticket [_1]", $ticket->Id ) . ': ' . $msg;
         }
