@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -48,7 +48,7 @@
 
 use strict;
 use warnings;
-use 5.10.1;
+use 5.26.3;
 
 package RT::Asset;
 use base 'RT::Record';
@@ -56,6 +56,7 @@ use base 'RT::Record';
 use Role::Basic "with";
 with "RT::Record::Role::Status",
      "RT::Record::Role::Links",
+     "RT::Record::Role::Scrip",
      "RT::Record::Role::Roles" => {
          -rename => {
              # We provide ACL'd wraps of these.
@@ -101,6 +102,52 @@ for my $role ('Owner', 'HeldBy', 'Contact') {
     );
 }
 
+RT::CustomRole->RegisterLookupType(
+    CustomFieldLookupType() => {
+        FriendlyName => 'Assets',
+        CreateGroupPredicate => sub {
+            my ($object, $role) = @_;
+            if ($object->isa('RT::Catalog')) {
+                # In case catalog level custom role groups got deleted
+                # somehow.  Allow to re-create them like default ones.
+                return $role->IsAdded($object->id);
+            }
+            elsif ($object->isa('RT::Asset')) {
+                # see if the role has been applied to the asset's catalog
+                # need to walk around ACLs
+                return $role->IsAdded($object->__Value('Catalog'));
+            }
+
+            return 0;
+        },
+        AppliesToObjectPredicate => sub {
+            my ($object, $role) = @_;
+            return 0 unless $object->CurrentUserHasRight('ShowCatalog');
+
+            # custom roles apply to catalogs, so canonicalize an asset
+            # into its catalog
+            if ($object->isa('RT::Asset')) {
+                $object = $object->CatalogObj;
+            }
+
+            if ($object->isa('RT::Catalog')) {
+                return $role->IsAdded($object->Id);
+            }
+
+            return 0;
+        },
+        Subgroup => {
+            Domain => 'RT::Asset-Role',
+            Table  => 'Assets',
+            Parent => 'Catalog',
+        },
+    }
+);
+
+# Assets can also take scrips
+RT::Scrip->RegisterLookupType( CustomFieldLookupType() => "Assets", );    #loc
+
+
 =head1 DESCRIPTION
 
 An Asset is a small record object upon which zero to many custom fields are
@@ -192,7 +239,7 @@ by ID.
 =item RefersTo, ReferredToBy, DependsOn, DependedOnBy, Parents, Children, and aliases
 
 Any of these link types accept either a single value or arrayref of values
-parseable by L<RT::URI>.
+parse-able by L<RT::URI>.
 
 =item LazyRoleGroups
 
@@ -262,7 +309,7 @@ sub Create {
     }
 
     my $roles = {};
-    my @errors = $self->_ResolveRoles( $roles, %args );
+    my @errors = $catalog->_ResolveRoles( $roles, %args );
     return (0, @errors) if @errors;
 
     RT->DatabaseHandle->BeginTransaction();
@@ -684,6 +731,37 @@ sub FindDependencies {
     $deps->Add( out => $self->CatalogObj );
 }
 
+sub CategoryObj {
+    my $self = shift;
+    return $self->CatalogObj;
+}
+
+sub __DependsOn {
+    my $self = shift;
+    my %args = (
+        Shredder     => undef,
+        Dependencies => undef,
+        @_,
+    );
+    my $deps = $args{'Dependencies'};
+    my $list = [];
+
+    # Asset role groups
+    my $objs = RT::Groups->new( $self->CurrentUser );
+    $objs->Limit( FIELD => 'Domain', VALUE => 'RT::Asset-Role', CASESENSITIVE => 0 );
+    $objs->Limit( FIELD => 'Instance', VALUE => $self->Id );
+    push( @$list, $objs );
+
+    $deps->_PushDependencies(
+        BaseObject    => $self,
+        Flags         => RT::Shredder::Constants::DEPENDS_ON,
+        TargetObjects => $list,
+        Shredder      => $args{'Shredder'}
+    );
+
+    return $self->SUPER::__DependsOn(%args);
+}
+
 RT::Base->_ImportOverlays();
 
 1;
