@@ -545,7 +545,8 @@ sub DoAuth {
             $RT::Logger->info(  "Successful login for",
                                 $session->{'CurrentUser'}->Name,
                                 "from",
-                                ( RT::Interface::Web::RequestENV('REMOTE_ADDR') || 'UNKNOWN') );
+                                ( RT::Interface::Web::RequestENV('HTTP_X_FORWARDED_FOR') ||
+                                  RT::Interface::Web::RequestENV('REMOTE_ADDR') || 'UNKNOWN') );
             # Do not delete the session. User stays logged in and
             # autohandler will not check the password again
 
