@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,10 +51,6 @@ package RT::Authen::Token;
 use strict;
 use warnings;
 
-use RT::System;
-
-'RT::System'->AddRight(Staff => ManageAuthTokens => 'Manage authentication tokens'); # loc
-
 use RT::AuthToken;
 use RT::AuthTokens;
 
@@ -90,7 +86,7 @@ sub UserForAuthString {
 
 =head1 NAME
 
-RT-Authen-Token - token-based authentication
+RT::Authen::Token - token-based authentication
 
 =head1 DESCRIPTION
 
@@ -116,6 +112,15 @@ Authentication tokens are stored securely (hashed and salted) in the
 database just like passwords, and so cannot be recovered after they are
 generated.
 
+=head2 Expires Date
+
+An optional Expires Date may be entered when creating an authentication
+token. If an authentication token has an Expires Date it will stop
+working after that date.
+
+Run the L<rt-email-expiring-auth-tokens> script to email users that have
+expiring auth tokens.
+
 =head2 Update your Apache configuration
 
 If you are running RT under Apache, add the following directive to your RT
@@ -124,4 +129,6 @@ Apache configuration to allow RT to access the Authorization header.
     SetEnvIf Authorization "(.*)" HTTP_AUTHORIZATION=$1
 =cut
 
+RT::Base->_ImportOverlays();
+
 1;
