@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -99,7 +99,7 @@ sub Create {
     my %args = ( Group           => '',
                  Member          => '',
                  ImmediateParent => '',
-                 Via             => '0',
+                 Via             => undef,
                  Disabled        => '0',
                  @_ );
 
@@ -141,7 +141,12 @@ sub Create {
                            . $args{'Via'} );
         return (undef);  #this will percolate up and bail out of the transaction
     }
-    if ( $self->__Value('Via') == 0 ) {
+
+    # Check $args{Via} instead of __Value('Via') to avoid cache issues on
+    # SQLite that may reuse ids: t/validator/group_members.t fails with
+    # __Value('Via')
+
+    if ( !$args{Via} ) {
         my ( $vid, $vmsg ) = $self->__Set( Field => 'Via', Value => $id );
         unless ($vid) {
             $RT::Logger->warning( "Due to a via error, couldn't create "
@@ -181,49 +186,11 @@ sub Create {
 
 
 
-=head2 Delete
-
-Deletes the current CachedGroupMember from the group it's in and
-cascades the delete to all submembers.
-
-=cut
-
-sub Delete {
-    my $self = shift;
-
-
-    my $member = $self->MemberObj();
-    if ( $member->IsGroup ) {
-        my $deletable = RT::CachedGroupMembers->new( $self->CurrentUser );
-
-        $deletable->Limit( FIELD    => 'id',
-                           OPERATOR => '!=',
-                           VALUE    => $self->id );
-        $deletable->Limit( FIELD    => 'Via',
-                           OPERATOR => '=',
-                           VALUE    => $self->id );
-
-        while ( my $kid = $deletable->Next ) {
-            my ($ok, $msg) = $kid->Delete();
-            unless ($ok) {
-                $RT::Logger->error(
-                    "Couldn't delete CachedGroupMember " . $kid->Id );
-                return ($ok, $msg);
-            }
-        }
-    }
-    my ($ok, $msg) = $self->SUPER::Delete();
-    $RT::Logger->error( "Couldn't delete CachedGroupMember " . $self->Id ) unless $ok;
-    return ($ok, $msg);
-}
-
-
-
 =head2 SetDisabled
 
 SetDisableds the current CachedGroupMember from the group it's in and cascades 
 the SetDisabled to all submembers. This routine could be completely excised if
-mysql supported foreign keys with cascading SetDisableds.
+MySQL supported foreign keys with cascading SetDisableds.
 
 =cut 
 
