@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -87,6 +87,11 @@ __PACKAGE__->AddRight( General => SeeCustomField        => 'View custom field va
 __PACKAGE__->AddRight( Staff   => ModifyCustomField     => 'Modify custom field values' ); # loc
 __PACKAGE__->AddRight( Staff   => SetInitialCustomField => 'Add custom field values only at object creation time'); # loc
 
+__PACKAGE__->AddRight( Admin => ModifyScrips   => 'Modify Scrips' );             # loc
+__PACKAGE__->AddRight( Admin => ShowScrips     => 'View Scrips' );               # loc
+__PACKAGE__->AddRight( Admin => ModifyTemplate => 'Modify Scrip templates' );    # loc
+__PACKAGE__->AddRight( Admin => ShowTemplate   => 'View Scrip templates' );      # loc
+
 RT::ACE->RegisterCacheHandler(sub {
     my %args = (
         Action      => "",
@@ -297,6 +302,28 @@ sub CurrentUserCanSee {
         || $self->CurrentUserHasRight('AdminCatalog');
 }
 
+=head2 CurrentUserCanCreate
+
+Returns true if the current user can create a new catalog, using I<AdminCatalog>.
+
+=cut
+
+sub CurrentUserCanCreate {
+    my $self = shift;
+    return $self->CurrentUserHasRight('AdminCatalog');
+}
+
+=head2 CurrentUserCanModify
+
+Returns true if the current user can modify the catalog, using I<AdminCatalog>.
+
+=cut
+
+sub CurrentUserCanModify {
+    my $self = shift;
+    return $self->CurrentUserHasRight('AdminCatalog');
+}
+
 =head2 Owner
 
 Returns an L<RT::User> object for this catalog's I<Owner> role group.  On error,
@@ -411,7 +438,7 @@ sub CacheNeedsUpdate {
     my $update = shift;
 
     if ($update) {
-        RT->System->SetAttribute(Name => 'CatalogCacheNeedsUpdate', Content => time);
+        RT->System->SetAttribute( Name => 'CatalogCacheNeedsUpdate', Content => Time::HiRes::time() );
         return;
     } else {
         my $attribute = RT->System->FirstAttribute('CatalogCacheNeedsUpdate');
@@ -511,6 +538,19 @@ sub FindDependencies {
     $objs->Limit( FIELD => 'Instance', VALUE => $self->Id );
     $deps->Add( in => $objs );
 
+    # Scrips
+    $objs = RT::ObjectScrips->new( $self->CurrentUser );
+    $objs->LimitToLookupType(RT::Asset->CustomFieldLookupType);
+    $objs->Limit( FIELD           => 'ObjectId',
+                  OPERATOR        => '=',
+                  VALUE           => $self->id,
+                  ENTRYAGGREGATOR => 'OR' );
+    $objs->Limit( FIELD           => 'ObjectId',
+                  OPERATOR        => '=',
+                  VALUE           => 0,
+                  ENTRYAGGREGATOR => 'OR' );
+    $deps->Add( in => $objs );
+
     # Custom Fields on assets _in_ this catalog
     $objs = RT::ObjectCustomFields->new( $self->CurrentUser );
     $objs->Limit( FIELD           => 'ObjectId',
@@ -586,6 +626,12 @@ sub __DependsOn {
     $objs->LimitToObjectId( $self->Id );
     push( @$list, $objs );
 
+    # Object Scrips
+    $objs = RT::ObjectScrips->new( $self->CurrentUser );
+    $objs->LimitToLookupType( RT::Asset->CustomFieldLookupType );
+    $objs->LimitToObjectId( $self->id );
+    push( @$list, $objs );
+
     $deps->_PushDependencies(
         BaseObject    => $self,
         Flags         => RT::Shredder::Constants::DEPENDS_ON,
@@ -595,6 +641,25 @@ sub __DependsOn {
     return $self->SUPER::__DependsOn(%args);
 }
 
+=head2 Templates
+
+Returns an RT::Templates object of all of this catalog's templates.
+
+=cut
+
+sub Templates {
+    my $self = shift;
+
+    my $templates = RT::Templates->new( $self->CurrentUser );
+
+    if ( $self->CurrentUserHasRight('ShowTemplate') ) {
+        $templates->LimitToObjectId( $self->id );
+        $templates->LimitToLookupType( RT::Asset->CustomFieldLookupType );
+    }
+
+    return ($templates);
+}
+
 RT::Base->_ImportOverlays();
 
 1;
