@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -105,6 +105,10 @@ __PACKAGE__->AddRight( Admin   => AdminTopics           => 'Modify topic hierarc
 __PACKAGE__->AddRight( Admin   => ShowACL               => 'Display Access Control List'); # loc
 __PACKAGE__->AddRight( Admin   => ModifyACL             => 'Create, modify and delete Access Control List entries'); # loc
 __PACKAGE__->AddRight( Staff   => DisableArticle        => 'Disable articles in this class'); # loc
+__PACKAGE__->AddRight( Admin   => ModifyScrips          => 'Modify Scrips' ); # loc
+__PACKAGE__->AddRight( Admin   => ShowScrips            => 'View Scrips' ); # loc
+__PACKAGE__->AddRight( Admin   => ModifyTemplate        => 'Modify Scrip templates' ); # loc
+__PACKAGE__->AddRight( Admin   => ShowTemplate          => 'View Scrip templates' ); # loc
 
 # {{{ Create
 
@@ -507,6 +511,39 @@ sub IncludeArticleCFValue {
     return $self->{'_cf_include_hash'}{"Value-".$cfobj->Id};
 }
 
+=head2 CurrentUserCanSee
+
+Returns true if the current user can see the class, using I<SeeClass>.
+
+=cut
+
+sub CurrentUserCanSee {
+    my $self = shift;
+    return $self->CurrentUserHasRight('SeeClass');
+}
+
+=head2 CurrentUserCanCreate
+
+Returns true if the current user can create a new class, using I<AdminClass>.
+
+=cut
+
+sub CurrentUserCanCreate {
+    my $self = shift;
+    return $self->CurrentUserHasRight('AdminClass');
+}
+
+=head2 CurrentUserCanModify
+
+Returns true if the current user can modify the class, using I<AdminClass>.
+
+=cut
+
+sub CurrentUserCanModify {
+    my $self = shift;
+    return $self->CurrentUserHasRight('AdminClass');
+}
+
 =head2 id
 
 Returns the current value of id. 
@@ -668,6 +705,19 @@ sub FindDependencies {
     $objectclasses->LimitToClass( $self->Id );
     $deps->Add( in => $objectclasses );
 
+    # Scrips
+    my $objs = RT::ObjectScrips->new( $self->CurrentUser );
+    $objs->LimitToLookupType(RT::Article->CustomFieldLookupType);
+    $objs->Limit( FIELD           => 'ObjectId',
+                  OPERATOR        => '=',
+                  VALUE           => $self->id,
+                  ENTRYAGGREGATOR => 'OR' );
+    $objs->Limit( FIELD           => 'ObjectId',
+                  OPERATOR        => '=',
+                  VALUE           => 0,
+                  ENTRYAGGREGATOR => 'OR' );
+    $deps->Add( in => $objs );
+
     # Custom Fields on things _in_ this class (CFs on the class itself
     # have already been dealt with)
     my $ocfs = RT::ObjectCustomFields->new( $self->CurrentUser );
@@ -734,6 +784,12 @@ sub __DependsOn {
     $objs->LimitToObjectId( $self->id );
     push( @$list, $objs );
 
+    # Object Scrips
+    $objs = RT::ObjectScrips->new( $self->CurrentUser );
+    $objs->LimitToLookupType( RT::Article->CustomFieldLookupType );
+    $objs->LimitToObjectId( $self->id );
+    push( @$list, $objs );
+
     # Topics
     $objs = RT::Topics->new( $self->CurrentUser );
     $objs->LimitToObject($self);
@@ -748,6 +804,25 @@ sub __DependsOn {
     return $self->SUPER::__DependsOn(%args);
 }
 
+=head2 Templates
+
+Returns an RT::Templates object of all of this class's templates.
+
+=cut
+
+sub Templates {
+    my $self = shift;
+
+    my $templates = RT::Templates->new( $self->CurrentUser );
+
+    if ( $self->CurrentUserHasRight('ShowTemplate') ) {
+        $templates->LimitToObjectId( $self->id );
+        $templates->LimitToLookupType( RT::Article->CustomFieldLookupType );
+    }
+
+    return ($templates);
+}
+
 RT::Base->_ImportOverlays();
 
 1;
