@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -50,7 +50,7 @@ use strict;
 use warnings;
 
 package RT::Crypt;
-use 5.010;
+use 5.26.3;
 
 use RT::Util ();
 
@@ -728,8 +728,14 @@ sub CheckRecipients {
         }
         my $user = RT::User->new( RT->SystemUser );
         $user->LoadByEmail( $address );
-        # it's possible that we have no User record with the email
-        $user = undef unless $user->id;
+        if ( $user->Id ) {
+            my $preferences = $user->Preferences( RT->System ) || {};
+            next if ( $preferences->{EmailFrequency} || RT->Config->Get('EmailFrequency') ) =~ /daily|weekly|suspend/i;
+        }
+        else {
+            # it's possible that we have no User record with the email
+            $user = undef;
+        }
 
         if ( my $fpr = RT::Crypt->UseKeyForEncryption( $address ) ) {
             if ( $res{'info'} && @{ $res{'info'} } ) {
@@ -901,4 +907,6 @@ sub GetKeysInfo {
     return $self->SimpleImplementationCall( %args );
 }
 
+RT::Base->_ImportOverlays();
+
 1;
