@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -61,7 +61,7 @@ use RT::Interface::Web;
 use File::Temp 'tempdir';
 use HTML::Scrubber;
 use URI::QueryParam;
-use List::MoreUtils 'uniq';
+use List::MoreUtils qw( any none uniq );
 
 sub MailDashboards {
     my $self = shift;
@@ -70,6 +70,10 @@ sub MailDashboards {
         DryRun => 0,
         Time   => time,
         User   => undef,
+        Dashboards => 0,
+        Recipients => undef,
+        Subscription => undef,
+        Test => 0,
         @_,
     );
 
@@ -78,6 +82,17 @@ sub MailDashboards {
     my $from = $self->GetFrom();
     $RT::Logger->debug("Sending email from $from");
 
+    my @dashboards;
+    if( $args{ Dashboards } ) {
+        @dashboards = split(/,/, $args{ Dashboards });
+        $RT::Logger->warning( "Non-numeric dashboard IDs are not permitted" ) if any{ /\D/ } @dashboards;
+        @dashboards = grep { /^\d+$/ } @dashboards;
+        if( @dashboards == 0 ) {
+            $RT::Logger->warning( "--dashboards option given but no valid dashboard IDs provided; exiting" );
+            return;
+        }
+    }
+
     # look through each user for her subscriptions
     my $Users = RT::Users->new(RT->SystemUser);
     $Users->LimitToPrivileged;
@@ -88,6 +103,36 @@ sub MailDashboards {
         $Users->Limit( FIELD => 'id', VALUE => $user->Id || 0 );
     }
 
+    my @recipients;
+    my %recipient_language;
+
+    if ( $args{Recipients} ) {
+        for my $recipient ( ref $args{Recipients} eq 'ARRAY' ? @{ $args{Recipients} } : $args{Recipients} ) {
+            my $user = RT::User->new( RT->SystemUser );
+            $user->Load($recipient);
+            if ( !$user->Id && $recipient =~ /@/ ) {
+                $user->LoadOrCreateByEmail($recipient);
+            }
+
+            if ( $user->Id ) {
+                if ( $user->Disabled ) {
+                    RT->Logger->error("User $recipient is disabled, exiting");
+                    return;
+                }
+                push @recipients, $user->EmailAddress;
+                $recipient_language{ $user->EmailAddress } = $user->Lang;
+            }
+            else {
+                RT->Logger->error("Could not load user $recipient, exiting");
+                return;
+            }
+        }
+    }
+
+    if ( $args{Subscription} ) {
+        $Users->Limit( FIELD => 'id', VALUE => $args{Subscription}->UserObj->Id || 0 );
+    }
+
     while (defined(my $user = $Users->Next)) {
         my ($hour, $dow, $dom) = HourDowDomIn($args{Time}, $user->Timezone || RT->Config->Get('Timezone'));
         $hour .= ':00';
@@ -98,43 +143,58 @@ sub MailDashboards {
 
         my $subscriber_lang = $user->Lang;
 
-        # look through this user's subscriptions, are any supposed to be generated
-        # right now?
-        for my $subscription ($user->Attributes->Named('Subscription')) {
+        my @subscriptions;
+        if ( $args{Subscription} ) {
+            push @subscriptions, $args{Subscription};
+        }
+        else {
+            my $collection = $user->DashboardSubscriptions;
+            $collection->Limit( FIELD => 'DashboardId', VALUE => \@dashboards, OPERATOR => 'IN' ) if @dashboards;
+            @subscriptions = @{ $collection->ItemsArrayRef };
+        }
+
+        for my $subscription (@subscriptions) {
             next unless $self->IsSubscriptionReady(
                 %args,
                 Subscription => $subscription,
                 User         => $user,
                 LocalTime    => [$hour, $dow, $dom],
+                Dashboards   => \@dashboards,
             );
 
-            my $recipients = $subscription->SubValue('Recipients');
-            my $recipients_users = $recipients->{Users};
-            my $recipients_groups = $recipients->{Groups};
+            my $content = $subscription->Content || {};
 
             my @emails;
-            my %recipient_language;
 
-            # add users' emails to email list
-            for my $user_id (@{ $recipients_users || [] }) {
-                my $user = RT::User->new(RT->SystemUser);
-                $user->Load($user_id);
-                next unless $user->id and !$user->Disabled;
-
-                push @emails, $user->EmailAddress;
-                $recipient_language{$user->EmailAddress} = $user->Lang;
+            if ( @recipients ) {
+                @emails = @recipients;
             }
+            else {
+                my $recipients = $content->{'Recipients'};
+                my $recipients_users = $recipients->{Users};
+                my $recipients_groups = $recipients->{Groups};
 
-            # add emails for every group's members
-            for my $group_id (@{ $recipients_groups || [] }) {
-                my $group = RT::Group->new(RT->SystemUser);
-                $group->Load($group_id);
-                next unless $group->id;
+                # add users' emails to email list
+                for my $user_id (@{ $recipients_users || [] }) {
+                    my $user = RT::User->new(RT->SystemUser);
+                    $user->Load($user_id);
+                    next unless $user->id and !$user->Disabled;
 
-                my $users = $group->UserMembersObj;
-                while (my $user = $users->Next) {
                     push @emails, $user->EmailAddress;
-                    $recipient_language{$user->EmailAddress} = $user->Lang;
+                    $recipient_language{ $user->EmailAddress } = $user->Lang;
+                }
+
+                # add emails for every group's members
+                for my $group_id (@{ $recipients_groups || [] }) {
+                    my $group = RT::Group->new(RT->SystemUser);
+                    $group->Load($group_id);
+                    next unless $group->id;
+
+                    my $users = $group->UserMembersObj;
+                    while (my $user = $users->Next) {
+                        push @emails, $user->EmailAddress;
+                        $recipient_language{ $user->EmailAddress } = $user->Lang;
+                    }
                 }
             }
 
@@ -144,7 +204,7 @@ sub MailDashboards {
                     my $lang;
                     for my $langkey (RT->Config->Get('EmailDashboardLanguageOrder')) {
                         if ($langkey eq '_subscription') {
-                            if ($lang = $subscription->SubValue('Language')) {
+                            if ($lang = $content->{'Language'}) {
                                 $RT::Logger->debug("Using subscription's specified language '$lang'");
                                 last;
                             }
@@ -179,7 +239,7 @@ sub MailDashboards {
                     }
 
                     my $context_user;
-                    if ( ( $subscription->SubValue( 'Context' ) // '' ) eq 'recipient' ) {
+                    if ( ( $content->{'Context'} // '' ) eq 'recipient' ) {
                         $context_user = RT::CurrentUser->new( RT->SystemUser );
                         my ( $ret, $msg ) = $context_user->LoadByEmail( $email );
                         unless ( $ret ) {
@@ -211,9 +271,9 @@ sub MailDashboards {
                 }
             }
 
-            if ($email_success) {
-                my $counter = $subscription->SubValue('Counter') || 0;
-                $subscription->SetSubValues(Counter => $counter + 1)
+            if ( $email_success && !$args{Test} ) {
+                my $counter = $content->{'Counter'} || 0;
+                $subscription->SetContent( { %$content, Counter => $counter + 1 } )
                     unless $args{DryRun};
             }
         }
@@ -227,24 +287,40 @@ sub IsSubscriptionReady {
         Subscription => undef,
         User         => undef,
         LocalTime    => [0, 0, 0],
+        Dashboards   => undef,
+        Test         => 0,
         @_,
     );
 
-    return 1 if $args{All};
+    my $subscription = $args{Subscription};
+    my $DashboardId  = $subscription->DashboardId;
+    my @dashboards   = @{ $args{ Dashboards } };
+    if( @dashboards and none { $_ == $DashboardId } @dashboards) {
+        $RT::Logger->info("Dashboard $DashboardId not in list of requested dashboards; skipping");
+        return;
+    }
 
-    my $subscription  = $args{Subscription};
+    my $dashboard = RT::Dashboard->new(RT->SystemUser);
+    $dashboard->Load($DashboardId);
+    if ( $dashboard->Disabled ) {
+        $RT::Logger->info("Dashboard $DashboardId is disabled; skipping");
+        return;
+    }
 
-    my $counter       = $subscription->SubValue('Counter') || 0;
+    # Check subscription frequency only once we're sure of the dashboard
+    return 1 if $args{All} || $args{Test};
 
-    my $sub_frequency = $subscription->SubValue('Frequency');
-    my $sub_hour      = $subscription->SubValue('Hour');
-    my $sub_dow       = $subscription->SubValue('Dow');
-    my $sub_dom       = $subscription->SubValue('Dom');
-    my $sub_fow       = $subscription->SubValue('Fow') || 1;
+    my $content = $subscription->Content || {};
+    my $counter       = $content->{'Counter'} || 0;
+    my $sub_frequency = $content->{'Frequency'};
+    my $sub_hour      = $content->{'Hour'};
+    my $sub_dow       = $content->{'Dow'};
+    my $sub_dom       = $content->{'Dom'};
+    my $sub_fow       = $content->{'Fow'} || 1;
 
     my $log_frequency = $sub_frequency;
     if ($log_frequency eq 'daily') {
-        my $days = join ' ', grep { $subscription->SubValue($_) }
+        my $days = join ' ', grep { $content->{$_} }
                              qw/Monday Tuesday Wednesday Thursday Friday
                                 Saturday Sunday/;
 
@@ -261,7 +337,7 @@ sub IsSubscriptionReady {
     return 0 if $sub_hour ne $hour;
 
     if ($sub_frequency eq 'daily') {
-        return $subscription->SubValue($dow) ? 1 : 0;
+        return $content->{$dow} ? 1 : 0;
     }
 
     if ($sub_frequency eq 'weekly') {
@@ -271,7 +347,7 @@ sub IsSubscriptionReady {
         # does it match the "every N weeks" clause?
         return 1 if $counter % $sub_fow == 0;
 
-        $subscription->SetSubValues(Counter => $counter + 1)
+        $subscription->SetContent( { %$content, Counter => $counter + 1 } )
             unless $args{DryRun};
         return 0;
     }
@@ -306,16 +382,19 @@ sub SendDashboard {
     my $context_user = $args{ContextUser} || $currentuser;
     my $subscription = $args{Subscription};
 
-    my $rows = $subscription->SubValue('Rows');
+    my $dashboard_content = $subscription->Content || {};
+    my $rows = $dashboard_content->{'Rows'};
 
-    my $DashboardId = $subscription->SubValue('DashboardId');
+    my $DashboardId = $subscription->DashboardId;
 
-    my $dashboard = RT::Dashboard->new($currentuser);
-    my ($ok, $msg) = $dashboard->LoadById($DashboardId);
+    my $dashboard = $subscription->DashboardObj;
 
     # failed to load dashboard. perhaps it was deleted or it changed privacy
-    if (!$ok) {
-        $RT::Logger->warning("Unable to load dashboard $DashboardId of subscription ".$subscription->Id." for user ".$currentuser->Name.": $msg");
+    if (!$dashboard->Id) {
+        $RT::Logger->warning( "Unable to load dashboard $DashboardId of subscription "
+                . $subscription->Id
+                . " for user "
+                . $currentuser->Name );
         return $self->ObsoleteSubscription(
             %args,
             Subscription => $subscription,
@@ -335,6 +414,9 @@ SUMMARY
 
     local $HTML::Mason::Commands::session{CurrentUser} = $currentuser;
     local $HTML::Mason::Commands::session{ContextUser} = $context_user;
+    local $HTML::Mason::Commands::session{WebDefaultStylesheet} = 'elevator';
+    local $RT::Config::OVERRIDDEN_OPTIONS{WebDefaultThemeMode}  = 'light';
+    local $HTML::Mason::Commands::session{_session_id}; # Make sure to not touch sessions table
     local $HTML::Mason::Commands::r = RT::Dashboard::FakeRequest->new;
 
     my $HasResults = undef;
@@ -346,7 +428,7 @@ SUMMARY
         HasResults => \$HasResults,
     );
 
-    if ($subscription->SubValue('SuppressIfEmpty')) {
+    if ($dashboard_content->{'SuppressIfEmpty'}) {
         # undef means there were no searches, so we should still send it (it's just portlets)
         # 0 means there was at least one search and none had any result, so we should suppress it
         if (defined($HasResults) && !$HasResults) {
@@ -361,8 +443,6 @@ SUMMARY
         }
     }
 
-    $content = ScrubContent($content);
-
     $RT::Logger->debug("Got ".length($content)." characters of output.");
 
     $content = HTML::RewriteAttributes::Links->rewrite(
@@ -398,7 +478,7 @@ sub ObsoleteSubscription {
         },
         ExtraHeaders => {
             'X-RT-Dashboard-Subscription-Id' => $subscription->Id,
-            'X-RT-Dashboard-Id' => $subscription->SubValue('DashboardId'),
+            'X-RT-Dashboard-Id' => ( $subscription->Content || {} )->{'DashboardId'},
         },
     );
 
@@ -417,6 +497,38 @@ sub ObsoleteSubscription {
     }
 }
 
+sub DashboardSubject {
+    my $self = shift;
+    my %args = (
+        CurrentUser  => undef,
+        Dashboard    => undef,
+        Subscription => undef,
+        @_,
+    );
+
+    my $subscription = $args{Subscription};
+    my $dashboard    = $args{Dashboard};
+    my $currentuser  = $args{CurrentUser};
+    my $frequency    = ( $subscription->Content || {} )->{'Frequency'};
+
+    my %frequency_lookup = (
+        'daily'   => 'Daily',   # loc
+        'weekly'  => 'Weekly',  # loc
+        'monthly' => 'Monthly', # loc
+        'never'   => 'Never',   # loc
+    );
+
+    my $frequency_display = $frequency_lookup{$frequency}
+                         || $frequency;
+
+    my $subject = sprintf '[%s] ' .  RT->Config->Get('DashboardSubject'),
+        RT->Config->Get('rtname'),
+        $currentuser->loc($frequency_display),
+        $dashboard->Name;
+
+    return $subject;
+}
+
 sub EmailDashboard {
     my $self = shift;
     my %args = (
@@ -433,23 +545,12 @@ sub EmailDashboard {
     my $currentuser  = $args{CurrentUser};
     my $email        = $args{Email};
 
-    my $frequency    = $subscription->SubValue('Frequency');
-
-    my %frequency_lookup = (
-        'daily'   => 'Daily',   # loc
-        'weekly'  => 'Weekly',  # loc
-        'monthly' => 'Monthly', # loc
-        'never'   => 'Never',   # loc
+    my $subject = $self->DashboardSubject(
+        CurrentUser  => $currentuser,
+        Dashboard    => $dashboard,
+        Subscription => $subscription,
     );
 
-    my $frequency_display = $frequency_lookup{$frequency}
-                         || $frequency;
-
-    my $subject = sprintf '[%s] ' .  RT->Config->Get('DashboardSubject'),
-        RT->Config->Get('rtname'),
-        $currentuser->loc($frequency_display),
-        $dashboard->Name;
-
     my $entity = $self->BuildEmail(
         %args,
         To      => $email,
@@ -474,6 +575,8 @@ sub EmailDashboard {
     $RT::Logger->debug("Done sending dashboard to ".$currentuser->Name." <$email>");
 }
 
+my $chrome;
+
 sub BuildEmail {
     my $self = shift;
     my %args = (
@@ -530,6 +633,152 @@ sub BuildEmail {
         inline_imports => 1,
     );
 
+    # This needs to be done after all of the CSS has been imported (by
+    # inline_css above, which is distinct from the work done by CSS::Inliner
+    # below) and before all of the scripts are scrubbed away.
+    if ( RT->Config->Get('EmailDashboardIncludeCharts') && $content =~ /<div class="chart-wrapper">/ ) {
+        # WWW::Mechanize::Chrome uses Log::Log4perl and calls trace sometimes.
+        # Here we merge trace to debug.
+        my $is_debug;
+        for my $type (qw/LogToSyslog LogToSTDERR LogToFile/) {
+            my $log_level = RT->Config->Get($type) or next;
+            if ( $log_level eq 'debug' ) {
+                $is_debug = 1;
+                last;
+            }
+        }
+
+        local *Log::Dispatch::is_trace = sub { $is_debug || 0 };
+        local *Log::Dispatch::trace    = sub {
+            my $self = shift;
+            return $self->debug(@_);
+        };
+
+        my ( $width, $height );
+        my @launch_arguments = RT->Config->Get('ChromeLaunchArguments');
+
+        for my $arg (@launch_arguments) {
+            if ( $arg =~ /^--window-size=(\d+)x(\d+)$/ ) {
+                $width  = $1;
+                $height = $2;
+                last;
+            }
+        }
+
+        $width  ||= 2560;
+        $height ||= 1440;
+
+        $chrome ||= WWW::Mechanize::Chrome->new(
+            autodie          => 0,
+            headless         => 1,
+            autoclose        => 1,
+            separate_session => 1,
+            log              => RT->Logger,
+            launch_arg       => \@launch_arguments,
+            launch_exe       => RT->Config->Get('ChromePath') || 'chromium',
+        );
+
+        # copy the content
+        my $content_with_script = $content;
+
+        # copy in the text of the linked js
+        $content_with_script
+            =~ s{<script type="text/javascript" src="([^"]+)"></script>}{<script type="text/javascript">@{ [(GetResource( $1 ))[0]] }</script>}g;
+
+        # write the complete content to a temp file
+        my $temp_fh = File::Temp->new(
+            UNLINK   => 1,
+            TEMPLATE => 'email-dashboard-XXXXXX',
+            SUFFIX   => '.html',
+            TMPDIR   => 1,
+        );
+        print $temp_fh Encode::encode( 'UTF-8', $content_with_script );
+        close $temp_fh;
+
+        $chrome->viewport_size( { width => $width, height => $height } );
+        $chrome->get_local( $temp_fh->filename );
+        $chrome->wait_until_visible( selector => 'div.dashboard' );
+
+        # grab the list of canvas elements
+        my @canvases = $chrome->selector('div.chart canvas');
+        if (@canvases) {
+
+            my $max_extent = 0;
+
+            # ... and their coordinates
+            foreach my $canvas_data (@canvases) {
+                my $coords = $canvas_data->{coords} = $chrome->element_coordinates($canvas_data);
+                if ( $max_extent < $coords->{top} + $coords->{height} ) {
+                    $max_extent = int( $coords->{top} + $coords->{height} ) + 1;
+                }
+            }
+
+            # make sure that all of them are "visible" in the headless instance
+            if ( $height < $max_extent ) {
+                $chrome->viewport_size( { width => $width, height => $max_extent } );
+            }
+
+            # capture the entire page as an image
+            my $page_image = $chrome->_content_as_png( undef, { width => $width, height => $height } )->get;
+
+            my $cid = time() . $$;
+            foreach my $canvas_data (@canvases) {
+                $cid++;
+
+                my $coords       = $canvas_data->{coords};
+                my $canvas_image = $page_image->crop(
+                    left   => $coords->{left},
+                    top    => $coords->{top},
+                    width  => $coords->{width},
+                    height => $coords->{height},
+                );
+                my $canvas_data;
+                $canvas_image->write( data => \$canvas_data, type => 'png' );
+
+                # replace each canvas in the original content with an image tag
+                $content =~ s{<canvas [^>]+>}{<img src="cid:$cid"/>};
+
+                push @parts,
+                    MIME::Entity->build(
+                        Top          => 0,
+                        Data         => $canvas_data,
+                        Type         => 'image/png',
+                        Encoding     => 'base64',
+                        Disposition  => 'inline',
+                        'Content-Id' => "<$cid>",
+                    );
+            }
+        }
+
+        # Shut down chrome if it's a test email from web UI, to reduce memory usage.
+        # Unset $chrome so next time it can re-create a new one.
+        if ( $args{Test} ) {
+            $chrome->close;
+            undef $chrome;
+        }
+    }
+
+    $content =~ s{<link rel="shortcut icon"[^>]+/>}{};
+
+    # Inline the CSS if CSS::Inliner is installed and can be loaded
+    if ( RT->Config->Get('EmailDashboardInlineCSS') ) {
+        if ( RT::StaticUtil::RequireModule('CSS::Inliner') ) {
+            # HTML::Query generates a ton of warnings about unsupported
+            # pseudoclasses. Suppress those since they don't help the person
+            # running RT.
+            local $SIG{__WARN__} = sub {};
+
+            my $inliner = CSS::Inliner->new( { encode_entities => 1, ignore_style_type_attr => 1 } );
+            $inliner->read({ html => $content });
+            $content = $inliner->inlinify();
+        }
+        else {
+            RT->Logger->warn('EmailDashboardInlineCSS is enabled but CSS::Inliner is not installed. Install the optional module CSS::Inliner to use this feature.');
+        }
+    }
+
+    $content = ScrubContent($content);
+
     my $entity = MIME::Entity->build(
         From    => Encode::encode("UTF-8", $args{From}),
         To      => Encode::encode("UTF-8", $args{To}),
@@ -605,6 +854,15 @@ sub BuildEmail {
             );
             # ... and <script>s
             $scrubber->deny('script');
+
+            # ... and the favicon image
+            $scrubber->rules(
+                link => {
+                    href => qr{(?<!favicon\.png)$},
+                    '*'  => 1,
+                },
+            );
+
         }
         return $scrubber;
     }
