@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -52,7 +52,7 @@ use strict;
 package RT::ExternalStorage::Disk;
 
 use File::Path qw//;
-
+use File::Basename 'dirname';
 use Role::Basic qw/with/;
 with 'RT::ExternalStorage::Backend';
 
@@ -85,12 +85,21 @@ sub IsWriteable {
     return (1);
 }
 
+sub _FilePath {
+    my $self = shift;
+    my $sha  = shift;
+
+    # fan out to avoid one gigantic directory which slows down all file access
+    $sha =~ m{^(...)(...)(.*)};
+    return $self->Path . "/$1/$2/$3";
+}
+
 sub Get {
     my $self = shift;
     my ($sha) = @_;
 
     $sha =~ m{^(...)(...)(.*)};
-    my $path = $self->Path . "/$1/$2/$3";
+    my $path = $self->_FilePath($sha);
 
     return (undef, "File does not exist") unless -e $path;
 
@@ -105,15 +114,11 @@ sub Get {
 sub Store {
     my $self = shift;
     my ($sha, $content, $attachment) = @_;
-
-    # fan out to avoid one gigantic directory which slows down all file access
-    $sha =~ m{^(...)(...)(.*)};
-    my $dir  = $self->Path . "/$1/$2";
-    my $path = "$dir/$3";
+    my $path = $self->_FilePath($sha);
 
     return ($sha) if -f $path;
 
-    File::Path::make_path($dir, {error => \my $err});
+    File::Path::make_path(dirname($path), {error => \my $err});
     return (undef, "Making directory failed") if @{$err};
 
     open( my $fh, ">:raw", $path ) or return (undef, "Cannot write file on disk: $!");
@@ -127,6 +132,17 @@ sub DownloadURLFor {
     return;
 }
 
+sub Delete {
+    my $self = shift;
+    my $sha  = shift;
+    my $path = $self->_FilePath($sha);
+
+    if ( -f $path ) {
+        unlink $path or return ( undef, "Cannot delete file: $!" );
+    }
+    return ($sha);
+}
+
 =head1 NAME
 
 RT::ExternalStorage::Disk - On-disk storage of attachments
@@ -135,7 +151,7 @@ RT::ExternalStorage::Disk - On-disk storage of attachments
 
     Set(%ExternalStorage,
         Type => 'Disk',
-        Path => '/opt/rt5/var/attachments',
+        Path => '/opt/rt6/var/attachments',
     );
 
 =head1 DESCRIPTION
