@@ -53,7 +53,7 @@ use warnings;
 use RT::Base;
 
 use base 'Exporter';
-our @EXPORT_OK = qw(CleanEnv GetCurrentUser debug loc Init);
+our @EXPORT_OK = qw(GetCurrentUser debug loc Init);
 
 =head1 NAME
 
@@ -86,7 +86,26 @@ RT::Interface::CLI - helper functions for creating a commandline RT interface
 
 =head1 DESCRIPTION
 
-The following methods can be loaded in your RT CLI script.
+This library provides shared functions for bootstrapping RT CLI programs
+that provide you with a fully functional environment for running code
+against the RT Perl API. When run, a database connection to the RT
+database is automatically set up.
+
+=head2 Memory Usage
+
+The CLI interface loads a full RT environment, which is convenient when
+creating command-line utilities because you can just start coding.
+However, there are parts of RT that are typically not needed in a CLI
+context and they contribute to the size of the running CLI process.
+You can reduce the size of these processes by disabling some of these
+features.
+
+The most effective way to reduce memory usage is to limit the languages
+loaded by RT. By default, RT loads all available translation lexicons,
+which can consume 40-50MB of memory. If your CLI script only needs English,
+you can use:
+
+    --config LexiconLanguages=en
 
 =head1 METHODS
 
@@ -175,6 +194,18 @@ It accepts log levels like C<$StatementLog>:
 
     --statement-log=debug
 
+C<config> provides a generic way to override any RT configuration option
+for the duration of the CLI script. It accepts key=value pairs where the
+key is the name of any RT configuration option. You can specify this option
+multiple times to set different configuration values.
+
+    --config LogLevel=debug
+    --config DisableGraphViz=1
+    --config LexiconLanguages=en,fr
+
+For array-valued options, use comma-separated values. For scalar options,
+provide the value directly. Hash-valued options are not fully supported yet.
+
 =cut
 
 sub Init {
@@ -224,6 +255,8 @@ sub Init {
     push @args, "statement-log=s" => \($hash->{'statement-log'})
         unless $exists{'statement-log'};
 
+    push @args, "config=s%" => \($hash->{config}) unless $exists{config};
+
     my $ok = Getopt::Long::GetOptions( @args );
     Pod::Usage::pod2usage(1) if not $ok and not defined wantarray;
 
@@ -246,6 +279,30 @@ sub Init {
         RT->Config->Set(LogToSTDERR => "warning");
     }
 
+    if ( $hash->{config} ) {
+        while ( my ($option, $value) = each %{$hash->{config}} ) {
+            my $meta = RT->Config->Meta($option) || {};
+            my $type = $meta->{Type} || 'SCALAR';
+
+            if ( $type eq 'ARRAY' ) {
+                # Parse comma-separated values for arrays
+                my @values = split /\s*,\s*/, $value;
+                RT->Config->Set( $option => @values );
+            }
+            elsif ( $type eq 'HASH' ) {
+                # For now, just warn that hashes aren't fully supported
+                RT->Logger->warning(
+                    "Hash-valued config option '$option' cannot be set via --config. " .
+                    "Use the config file or a specific CLI option instead."
+                );
+            }
+            else {
+                # Scalar value
+                RT->Config->Set( $option => $value );
+            }
+        }
+    }
+
     RT->Config->Set( 'StatementLog', $hash->{'statement-log'} ) if defined $hash->{'statement-log'};
     RT::Init();
     $RT::Handle->LogSQLStatements(1) if RT->Config->Get('StatementLog');
