@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,6 +51,7 @@ use warnings;
 use strict;
 
 use RT::CurrentUser;
+use Clone;
 
 =head1 NAME
 
@@ -316,6 +317,187 @@ sub ClearByUser {
     $self->ClearOrphanLockFiles if $deleted;
 }
 
+=head3 Load
+
+Load a session or create a new one.
+
+Accepts: Ref, Id
+
+Ref is a reference to a hash which will be loaded with
+session data.
+
+Id is the id of an existing session. If set to undef or
+omitted, an empty new session will be created with a session id
+set with the key '_session_id'.
+
+=cut
+
+sub Load {
+    my %args = (
+        Ref => \%HTML::Mason::Commands::session,
+        Id  => undef,
+        @_
+    );
+
+    my %local_session;
+    tie %local_session, 'RT::Interface::Web::Session', $args{'Id'};
+
+    # Use { %local_session } instead of \%local_session to not clone the tie part.
+    %{ $args{'Ref'} } = %{ Clone::clone( {%local_session} ) };
+
+    untie %local_session;
+
+    return 1;
+}
+
+=head3 Set
+
+Set a value in the session.
+
+Accepts: Ref, Key, SubKey, SubSubKey, Value
+
+Ref is a reference to a hash for an existing session.
+It is expected to have a key '_session_id' with the id of the
+current session. The referenced hash will be also be updated
+with the new value.
+
+Key and the SubKey parameters indicate where in the hash
+to set the value. The multiple subkey arguments handle multiple
+hash levels from the previous direct hash implementation.
+
+Value is the value to set in the indicated key.
+
+If _session_id is not set, it simply updates Ref.
+
+=cut
+
+sub Set {
+    my %args = (
+        Ref => \%HTML::Mason::Commands::session,
+        Key       => undef,
+        SubKey    => undef,
+        SubSubKey => undef,
+        Value     => undef,
+        @_
+    );
+
+    my $session_id = $args{'Ref'}->{'_session_id'};
+
+    my %local_session;
+    my $target;
+
+    if ($session_id) {
+        tie %local_session, 'RT::Interface::Web::Session', $session_id;
+        $target = \%local_session;
+    }
+    else {
+        # No session_id means not tied, in which case Ref is a plain hashref.
+        $target = $args{'Ref'};
+    }
+
+    # Set the value, which will automagically set it in the back-end session storage
+    if ( defined $args{'SubSubKey'} ) {
+        $target->{ $args{'Key'} }{ $args{'SubKey'} }{ $args{'SubSubKey'} } = $args{'Value'};
+    }
+    elsif ( defined $args{'SubKey'} ) {
+        $target->{ $args{'Key'} }{ $args{'SubKey'} } = $args{'Value'};
+    }
+    else {
+        $target->{ $args{'Key'} } = $args{'Value'};
+    }
+
+    if ( tied %local_session ) {
+
+        # Clone it back so we update the copy of the session with the latest values
+        # Use { %local_session } instead of \%local_session to not clone the tie part.
+        %{ $args{'Ref'} } = %{ Clone::clone( {%local_session} ) };
+
+        # Apache::Session doesn't sync changes to subkeys, so force a sync
+        # with a change at the top level.
+        $local_session{i}++;
+
+        untie %local_session;
+    }
+
+    return 1;
+}
+
+=head3 Delete
+
+Delete a key from the session.
+
+Accepts: Ref, Key, SubKey, SubSubKey
+
+Ref is a reference to a hash for an existing session.
+It is expected to have a key '_session_id' with the id of the
+current session. The referenced hash will be also be updated
+with the new value.
+
+Key and the SubKey parameters indicate where in the hash
+to delete the key. The multiple subkey arguments handle multiple
+hash levels from the previous direct hash implementation.
+
+If _session_id is not set, it simply deletes from Ref.
+
+=cut
+
+sub Delete {
+    my %args = (
+        Ref       => \%HTML::Mason::Commands::session,
+        Key       => undef,
+        SubKey    => undef,
+        SubSubKey => undef,
+        @_
+    );
+
+    my $session_id = $args{'Ref'}->{'_session_id'};
+    my %local_session;
+
+    my $target;
+
+    if ($session_id) {
+        tie %local_session, 'RT::Interface::Web::Session', $session_id;
+        $target = \%local_session;
+    }
+    else {
+        # No session_id means not tied, in which case Ref is a plain hashref.
+        $target = $args{'Ref'};
+    }
+
+    if ( $args{'Key'} ) {
+
+        # Delete requested item from the session
+        if ( defined $args{'SubSubKey'} ) {
+            delete $target->{ $args{'Key'} }{ $args{'SubKey'} }{ $args{'SubSubKey'} };
+        }
+        elsif ( defined $args{'SubKey'} ) {
+            delete $target->{ $args{'Key'} }{ $args{'SubKey'} };
+        }
+        else {
+            delete $target->{ $args{'Key'} };
+        }
+
+        if ( tied %local_session ) {
+
+            # Apache::Session doesn't sync changes to subkeys, so force a sync
+            # with a change at the top level.
+            $local_session{i}++;
+
+            # Use { %local_session } instead of \%local_session to not clone the tie part.
+            %{ $args{'Ref'} } = %{ Clone::clone( {%local_session} ) };
+        }
+    }
+    else {
+        # No key provided, delete the whole session
+        tied(%local_session)->delete if tied %local_session;
+        %{ $args{'Ref'} } = ();
+    }
+
+    untie %local_session if tied %local_session;
+
+    return 1;
+}
+
 sub TIEHASH {
     my $self = shift;
     my $id = shift;
@@ -337,4 +519,6 @@ sub TIEHASH {
     return tied %session;
 }
 
+RT::Base->_ImportOverlays();
+
 1;
