@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -48,7 +48,7 @@
 
 package RT::ObjectCustomFieldValue;
 
-use 5.010;
+use 5.26.3;
 use strict;
 use warnings;
 use base 'RT::Record';
@@ -407,8 +407,8 @@ sub _FillInTemplateURL {
 =head2 ValueLinkURL
 
 Returns a filled in URL template for this ObjectCustomFieldValue, suitable for 
-constructing a hyperlink in RT's webui. Returns undef if this custom field doesn't have
-a LinkValueTo
+constructing a hyperlink in RT's web UI. Returns undef if this custom field
+doesn't have a LinkValueTo
 
 =cut
 
@@ -846,6 +846,39 @@ sub _ContentIsPermissive {
     return $self->CustomFieldObj->_ContentIsPermissive;
 }
 
+sub __DependsOn {
+    my $self = shift;
+    my %args = (
+        Shredder     => undef,
+        Dependencies => undef,
+        @_,
+    );
+    my $deps = $args{'Dependencies'};
+    my $list = [];
+
+    # fulltext index
+    my $fts = RT->Config->Get('FullTextSearch');
+    if ( $fts && $fts->{Indexed} && $fts->{CFTable} ) {
+        require RT::Shredder::RawRecord;
+        push @$list,
+            RT::Shredder::RawRecord->new(
+                CurrentUser => $self->CurrentUser,
+                Table       => $fts->{CFTable},
+                Columns     => {
+                    id => $self->Id,
+                },
+            );
+    }
+
+    $deps->_PushDependencies(
+        BaseObject    => $self,
+        Flags         => RT::Shredder::Constants::DEPENDS_ON,
+        TargetObjects => $list,
+        Shredder      => $args{'Shredder'}
+    );
+    return $self->SUPER::__DependsOn(%args);
+}
+
 RT::Base->_ImportOverlays();
 
 1;
