@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -60,6 +60,10 @@ use Module::Pluggable (
     sub_name    => '_resource_classes',
     require     => 1,
     max_depth   => 5,
+
+    # Overlay files will be loaded by vanilla modules. Exclude them here so vanilla modules can be loaded first.
+    # Old perl versions might not support variable length lookbehind like qr/(?<!_Overlay|_Vendor|_Local)/
+    file_regex  => qr/(?<!_Overlay)(?<!_Vendor)(?<!_Local)\.pm$/,
 );
 
 has _dispatcher => (
@@ -121,4 +125,6 @@ sub to_psgi_app {
     };
 }
 
+RT::Base->_ImportOverlays();
+
 1;
