@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -421,9 +421,16 @@ sub CanonicalizePrincipal {
         if ($args{User}) {
             my $name = delete $args{User};
             # Sanity check the address
-            return (0, $self->loc("[_1] is an address RT receives mail at. Adding it as a '[_2]' would create a mail loop",
-                                  $name, $self->loc($args{Type}) ))
-                if $args{ExcludeRTAddress} && RT::EmailParser->IsRTAddress( $name );
+            return (
+                0,
+                $self->loc(
+                    "[_1] is an address RT receives mail at. Adding it as a '[_2]' would create a mail loop",
+                    UNIVERSAL::isa( $name, 'RT::User' ) ? $name->EmailAddress : $name,
+                    $self->loc( $args{Type} )
+                )
+                )
+                if $args{ExcludeRTAddress}
+                && RT::EmailParser->IsRTAddress( UNIVERSAL::isa( $name, 'RT::User' ) ? $name->EmailAddress : $name );
 
             # Create as the SystemUser, not the current user
             my $user = RT::User->new(RT->SystemUser);
@@ -527,7 +534,7 @@ sub AddRoleMember {
     return (0, $self->loc('[_1] cannot be a group', $group->Label) )
                 if $group->SingleMemberRoleGroup and $principal->IsGroup;
 
-    ( (my $ok), $msg ) = $group->_AddMember( %args, PrincipalId => $principal->Id, RecordTransaction => !$args{Silent} );
+    ( (my $ok), $msg ) = $group->_AddMember( %args, Object => $self, PrincipalId => $principal->Id, RecordTransaction => !$args{Silent} );
     unless ($ok) {
         $RT::Logger->error("Failed to add principal ".$principal->Id." as a member of group ".$group->Id.": ".$msg);
 
@@ -589,7 +596,8 @@ sub DeleteRoleMember {
                             $principal->Object->Name, $self->loc($args{Type}) ) )
         unless $group->HasMember($principal);
 
-    ((my $ok), $msg) = $group->_DeleteMember($principal->Id, RecordTransaction => !$args{Silent});
+    ( ( my $ok ), $msg )
+        = $group->_DeleteMember( $principal->Id, Object => $self, RecordTransaction => !$args{Silent} );
     unless ($ok) {
         $RT::Logger->error("Failed to remove ".$principal->Id." as a member of group ".$group->Id.": ".$msg);
 
@@ -821,7 +829,7 @@ sub LabelForRole {
     if ($role->{LabelGenerator}) {
         return $role->{LabelGenerator}->($self);
     }
-    return $role->{Name};
+    return blessed $self ? $self->loc( $role->{Name} ) : $role->{Name};
 }
 
 =head1 OPTIONS
@@ -895,4 +903,6 @@ sub RoleAddresses {
     return undef;
 }
 
+RT::Base->_ImportOverlays();
+
 1;
