@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2022 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -59,6 +59,11 @@ use constant _Queue => undef;
 
 sub Prepare {
     my $self = shift;
+
+    unless ( $self->TicketObj ) {
+        return (0);
+    }
+
     if ( $self->_Queue ) {
         my $queue = RT::Queue->new( RT->SystemUser );
         $queue->Load( $self->TicketObj->__Value('Queue') );
