@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -66,13 +66,13 @@ package RT::SearchBuilder;
 
 use strict;
 use warnings;
-use 5.010;
+use 5.26.3;
 
 use base qw(DBIx::SearchBuilder RT::Base);
 $DBIx::SearchBuilder::PREFER_BIND = 1 unless defined $ENV{SB_PREFER_BIND};
 
 use RT::Base;
-use DBIx::SearchBuilder "1.40";
+use DBIx::SearchBuilder;
 
 use Scalar::Util qw/blessed/;
 
@@ -96,6 +96,8 @@ sub CleanSlate {
     $self->{'_sql_aliases'} = {};
     delete $self->{'handled_disabled_column'};
     delete $self->{'find_disabled_rows'};
+    delete $self->{'_split_query'};
+    delete $self->{'_untamed_order_by'};
     return $self->SUPER::CleanSlate(@_);
 }
 
@@ -169,8 +171,15 @@ sub _OrderByCF {
         ENTRYAGGREGATOR => 'AND'
     );
 
-    return { %$row, ALIAS => $CFvs,  FIELD => 'SortOrder' },
-           { %$row, ALIAS => $ocfvs, FIELD => 'Content' };
+    return { %$row, ALIAS => $CFvs, FIELD => 'SortOrder' },
+        {
+            %$row,
+            ALIAS => $ocfvs,
+            FIELD => 'Content',
+            blessed $cf && $cf->IsNumeric
+            ? ( FUNCTION => RT->DatabaseHandle->CastAsDecimal('Content') )
+            : ()
+        };
 }
 
 sub OrderByCols {
@@ -267,6 +276,22 @@ sub RecordClass {
     $_[0]->_SingularClass
 }
 
+=head2 ReportClass
+
+Returns report class name of this collection. E.g. report class of RT::Tickets
+is RT::Report::Tickets
+
+=cut
+
+sub ReportClass {
+    my $self = shift;
+    my $class = ref($self) || $self;
+    if ( $class =~ s/(?<=^RT::)/Report::/ ) {
+        return $class;
+    }
+    return undef;
+}
+
 =head2 RegisterCustomFieldJoin
 
 Takes a pair of arguments, the first a class name and the second a callback
@@ -529,9 +554,21 @@ sub _LimitCustomField {
 
 
     my $fix_op = sub {
+        my %args = @_;
+
+        if (   $args{'FIELD'} eq 'Content'
+            && blessed $cf
+            && $cf->IsNumeric
+            && $args{'OPERATOR'} !~ m/LIKE/i
+            && ( !$args{QUOTEVALUE} || Scalar::Util::looks_like_number($args{'VALUE'}) ) )
+        {
+            $args{QUOTEVALUE} = 0;
+            $args{FUNCTION} = RT->DatabaseHandle->CastAsDecimal( "$args{ALIAS}.$args{FIELD}" );
+            return %args;
+        }
+
         return @_ unless RT->Config->Get('DatabaseType') eq 'Oracle';
 
-        my %args = @_;
         return %args unless $args{'FIELD'} eq 'LargeContent';
 
         my $op = $args{'OPERATOR'};
@@ -827,17 +864,18 @@ sub _LimitCustomField {
         );
     } else {
         # Otherwise, go looking at the Content
-        $self->Limit(
+        $self->Limit( $fix_op->(
             %args,
             ALIAS    => $ocfvalias,
             FIELD    => 'Content',
             OPERATOR => $op,
             VALUE    => $value,
             CASESENSITIVE => 0,
-        );
+        ) );
     }
 
-    if (!$value_is_long and $op eq "=") {
+    if ( ( blessed($cf) and $cf->IsNumeric ) or ( !$value_is_long and $op eq "=" ) ) {
+        # Skip LargeContent comparison for numeric values.
         # Doesn't matter what LargeContent contains, as it cannot match
         # the short value.
     } elsif (!$value_is_long and $op =~ /^(!=|<>)$/) {
@@ -924,7 +962,7 @@ sub _LimitCustomField {
 
 This Limit sub calls SUPER::Limit, but defaults "CASESENSITIVE" to 1, thus
 making sure that by default lots of things don't do extra work trying to 
-match lower(colname) agaist lc($val);
+match lower(colname) against lc($val);
 
 We also force VALUE to C<NULL> when the OPERATOR is C<IS> or C<IS NOT>.
 This ensures that we don't pass invalid SQL to the database or allow SQL
@@ -983,7 +1021,7 @@ sub Limit {
     if ( $table and $ARGS{FIELD} and my $instead = $deprecated{ lc $table }{ lc $ARGS{'FIELD'} } ) {
         RT->Deprecated(
             Message => "$table.$ARGS{'FIELD'} column is deprecated",
-            Instead => $instead, Remove => '5.2'
+            Instead => $instead, Remove => '6.2'
         );
     }
 
@@ -1150,6 +1188,117 @@ sub DistinctFieldValues {
     return @values;
 }
 
+sub CurrentUserCanSeeAll {
+    my $self = shift;
+    return 1 if $self->{_current_user_can_see_all};
+    return $self->CurrentUser->HasRight( Right => 'SuperUser', Object => RT->System ) ? 1 : 0;
+}
+
+sub BuildSelectQuery {
+    my $self = shift;
+    return $self->_BuildQuery('BuildSelectQuery', @_);
+}
+
+sub BuildSelectCountQuery {
+    my $self = shift;
+    return $self->_BuildQuery('BuildSelectCountQuery', @_);
+}
+
+sub BuildSelectAndCountQuery {
+    my $self = shift;
+    return $self->_BuildQuery('BuildSelectAndCountQuery', @_);
+}
+
+sub _BuildQuery {
+    my $self   = shift;
+    my $method = shift;
+    if ( my $query = $self->{_split_query} ) {
+        my $objects = $self->new( $self->CurrentUser );
+        if ( RT->Config->Get('DatabaseType') eq 'mysql' ) {
+            $objects->Limit( FIELD => 'id', VALUE => "(SELECT * from ($query) AS T)", OPERATOR => 'IN', QUOTEVALUE => 0 );
+        }
+        else {
+            $objects->Limit( FIELD => 'id', VALUE => "($query)", OPERATOR => 'IN', QUOTEVALUE => 0 );
+        }
+
+        # Sync page and columns related info
+        $objects->{$_} = $self->{$_} for qw/first_row show_rows columns/;
+
+        # Sync order by
+        if ( $self->{_untamed_order_by} ) {
+            $objects->OrderByCols( @{ $self->{_untamed_order_by} } );
+        }
+        elsif ( $self->{_order_by} ) {
+            $objects->OrderByCols( @{ $self->{_order_by} } );
+        }
+
+        my $query = $objects->$method(@_);
+        $self->{_bind_values} = $objects->{_bind_values};
+        return $query;
+    }
+    my $super = "SUPER::$method";
+    return $self->$super(@_);
+}
+
+sub _SplitQuery {
+    my $self = shift;
+
+    # SQLite doesn't support user defined precedences via parens for INTERSECT/UNION operations.
+    return if RT->Config->Get('DatabaseType') eq 'SQLite';
+
+    my $query = shift;
+    return unless $query;
+
+    return unless $self->can('SplitFields');
+    my @fields = $self->SplitFields;
+    return unless @fields;
+
+    my $tree = RT::Interface::Web::QueryBuilder::Tree->new;
+    $tree->ParseSQL(
+        Query       => $query,
+        CurrentUser => $self->CurrentUser,
+        Class       => ref $self,
+    );
+
+    my $split;
+    my %intersect_exists;
+    my @union_queries;
+    for my $intersect ( $tree->Split( Type => 'intersect', Fields => \@fields ) ) {
+        my $query = join ' ', map { $_->{TEXT} } @{ $intersect->__LinearizeTree };
+        next if $intersect_exists{$query}++;
+
+        my @union_selects;
+        my %union_exists;
+        for my $union ( $intersect->Split( Type => 'union', Fields => \@fields ) ) {
+            my $query = join ' ', map { $_->{TEXT} } @{ $union->__LinearizeTree };
+            next if $union_exists{$query}++;
+
+            my @intersects = $union->Split( Type => 'intersect', Fields => \@fields );
+            if ( @intersects > 1 ) {
+                push @union_selects, $self->_SplitQuery($query);
+            }
+            else {
+                my $collection = $self->new( $self->CurrentUser );
+                $collection->{_no_split} = 1;
+
+                $collection->FromSQL($query);
+                $collection->OrderByCols();
+                $collection->CurrentUserCanSee
+                    if RT->Config->Get('UseSQLForACLChecks') && $collection->can('CurrentUserCanSee');
+                $collection->Columns('id');
+                push @union_selects, $collection->BuildSelectQuery( PreferBind => 0 );
+            }
+        }
+        push @union_queries, '( ' . join( ' UNION ', @union_selects ) . ' )';
+        $split = 1 if @union_selects > 1;
+    }
+
+    $split = 1 if @union_queries > 1;
+    return unless $split; # Return empty if the query is not split.
+
+    return '(' . join( ' INTERSECT ', @union_queries ) . ')';
+}
+
 RT::Base->_ImportOverlays();
 
 1;
