@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -78,6 +78,13 @@ kilobytes or megabytes.
 
 sub SupportArgs { return $_[0]->SUPER::SupportArgs, qw(files_only file longer) }
 
+# used to generate checkboxes instead of text fields in the web interface
+sub ArgIsBoolean {
+    my( $self, $arg ) = @_;
+    my %boolean_atts = map { $_ => 1 } qw( files_only );
+    return $boolean_atts{$arg};
+}
+
 sub TestArgs
 {
     my $self = shift;
@@ -132,10 +139,12 @@ sub Run
     }
     return (0, "Internal error: '". $sth->err ."'. Please send bug report.") if $sth->err;
 
-    map { $_ = "RT::Attachment-$_" } @objs;
+    @objs = map {"RT::Attachment-$_"} @objs;
 
     return (1, @objs);
 }
 
+RT::Base->_ImportOverlays();
+
 1;
 
