@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2022 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -49,11 +49,11 @@
 =head1 SYNOPSIS
 
   use RT::Squish::CSS;
-  my $squish = RT::Squish::CSS->new( Style => 'elevator-light');
+  my $squish = RT::Squish::CSS->new( Style => 'elevator');
 
 =head1 DESCRIPTION
 
-This module lets you create squished content of css files.
+This module lets you create squished content of CSS files.
 
 =head1 METHODS
 
@@ -70,7 +70,7 @@ __PACKAGE__->mk_accessors(qw/Style/);
 
 =head2 Squish
 
-use CSS::Squish to squish css
+use CSS::Squish to squish CSS
 
 =cut
 
@@ -91,4 +91,6 @@ sub Filter {
     return CSS::Minifier::XS::minify($content);
 }
 
+RT::Base->_ImportOverlays();
+
 1;
