@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -73,12 +73,13 @@ use warnings;
 use base qw/RT::Record/;
 
 use Role::Basic 'with';
-with "RT::Record::Role::Roles",
+with "RT::Record::Role::Roles", "RT::Record::Role::Principal" => { -excludes => [ 'PrincipalId' ] },
      "RT::Record::Role::Rights" => { -excludes => [qw/AvailableRights RightCategories/] };
 
 use RT::ACL;
 use RT::ACE;
 use Data::GUID;
+use Time::HiRes;
 
 __PACKAGE__->AddRight( Admin   => SuperUser           => 'Do anything and everything'); # loc
 __PACKAGE__->AddRight( Staff   => ShowUserHistory     => 'Show history of public user properties'); # loc
@@ -91,11 +92,24 @@ __PACKAGE__->AddRight( Admin   => ShowApprovalsTab    => 'Show Approvals tab');
 __PACKAGE__->AddRight( Staff   => ShowAssetsMenu      => 'Show Assets menu'); # loc
 __PACKAGE__->AddRight( Staff   => ShowGlobalTemplates => 'Show global templates'); # loc
 __PACKAGE__->AddRight( General => LoadSavedSearch     => 'Allow loading of saved searches'); # loc
-__PACKAGE__->AddRight( General => CreateSavedSearch   => 'Allow creation of saved searches'); # loc
 __PACKAGE__->AddRight( Admin   => ExecuteCode         => 'Allow writing Perl code in templates, scrips, etc'); # loc
 __PACKAGE__->AddRight( General => SeeSelfServiceGroupTicket => 'See tickets for other group members in SelfService' ); # loc
 __PACKAGE__->AddRight( Staff   => ShowSearchAdvanced    => 'Show search "Advanced" menu' ); # loc
 __PACKAGE__->AddRight( Staff   => ShowSearchBulkUpdate  => 'Show search "Bulk Update" menu' ); # loc
+__PACKAGE__->AddRight( Admin   => AdminTimesheets     => 'Add time worked for other users' ); # loc
+__PACKAGE__->AddRight( Staff   => ManageAuthTokens    => 'Manage authentication tokens' );    # loc
+
+__PACKAGE__->AddRight( General => SeeSavedSearch      => 'View system saved searches' );                           # loc
+__PACKAGE__->AddRight( Admin   => AdminSavedSearch    => 'Create, update, and delete system saved searches' );     # loc
+__PACKAGE__->AddRight( Staff   => SeeOwnSavedSearch   => 'View personal saved searches' );                         # loc
+__PACKAGE__->AddRight( Staff   => AdminOwnSavedSearch => 'Create, update and delete personal saved searches' );    # loc
+
+__PACKAGE__->AddRight( Staff   => SubscribeDashboard => 'Subscribe to dashboards' );                          # loc
+__PACKAGE__->AddRight( General => SeeDashboard       => 'View system dashboards' );                           # loc
+__PACKAGE__->AddRight( Admin   => AdminDashboard     => 'Create, update, and delete system dashboards' );     # loc
+__PACKAGE__->AddRight( Staff   => SeeOwnDashboard    => 'View personal dashboards' );                         # loc
+__PACKAGE__->AddRight( Staff   => AdminOwnDashboard  => 'Create, update and delete personal dashboards' );    # loc
+
 
 =head2 AvailableRights
 
@@ -199,7 +213,7 @@ sub SubjectTag {
 
 Attribute to decide when SelectQueue needs to flush the list of queues
 and retrieve new ones.  Set when queues are created, enabled/disabled
-and on certain acl changes.  Should also better understand group management.
+and on certain ACL changes.  Should also better understand group management.
 
 If passed a true value, will update the attribute to be the current time.
 
@@ -210,7 +224,7 @@ sub QueueCacheNeedsUpdate {
     my $update = shift;
 
     if ($update) {
-        return $self->SetAttribute(Name => 'QueueCacheNeedsUpdate', Content => time);
+        return $self->SetAttribute( Name => 'QueueCacheNeedsUpdate', Content => Time::HiRes::time() );
     } else {
         my $cache = $self->FirstAttribute('QueueCacheNeedsUpdate');
         return (defined $cache ? $cache->Content : 0 );
@@ -231,19 +245,19 @@ sub CustomRoleCacheNeedsUpdate {
     my $update = shift;
 
     if ($update) {
-        return $self->SetAttribute(Name => 'CustomRoleCacheNeedsUpdate', Content => time);
+        return $self->SetAttribute( Name => 'CustomRoleCacheNeedsUpdate', Content => Time::HiRes::time() );
     } else {
         my $cache = $self->FirstAttribute('CustomRoleCacheNeedsUpdate');
         return (defined $cache ? $cache->Content : 0 );
     }
 }
 
-=head2 ConfigCacheNeedsUpdate ( 1 )
+=head2 ConfigCacheNeedsUpdate ( EPOCH )
 
 Attribute to decide when we need to flush the database settings
 and re-register any changes.  Set when settings are created, enabled/disabled, etc.
 
-If passed a true value, will update the attribute to be the current time.
+If passed an epoch time, will update the attribute to it.
 
 =cut
 
@@ -260,7 +274,7 @@ sub ConfigCacheNeedsUpdate {
 }
 
 # This needs to be in RT::System as RT::Interface::Web and RT::Interface::Email both use this
-my $lifecycle_cache_time = time;
+my $lifecycle_cache_time = Time::HiRes::time();
 sub MaybeRebuildLifecycleCache {
     my $needs_update = RT->System->LifecycleCacheNeedsUpdate;
     if ( $needs_update > $lifecycle_cache_time ) {
@@ -283,7 +297,7 @@ sub LifecycleCacheNeedsUpdate {
     my $update = shift;
 
     if ($update) {
-        return $self->SetAttribute(Name => 'LifecycleCacheNeedsUpdate', Content => time);
+        return $self->SetAttribute( Name => 'LifecycleCacheNeedsUpdate', Content => Time::HiRes::time() );
     }
     else {
         my $cache = $self->FirstAttribute('LifecycleCacheNeedsUpdate');
@@ -442,11 +456,69 @@ sub ExternalStorageURLFor {
     # external storage direct links disabled
     return undef if !RT->Config->Get('ExternalStorageDirectLink');
 
-    return undef unless $Object->ContentEncoding eq 'external';
+    # If current user doesn't have rights, ContentEncoding is undef
+    return undef unless ( $Object->ContentEncoding // '' ) eq 'external';
 
     return $self->ExternalStorage->DownloadURLFor($Object);
 }
 
+# Catalog of message codes and user messages
+our %USER_MESSAGES;
+%USER_MESSAGES = (
+    'SQLTimeout' => 'Your query exceeded the maximum run time and was stopped. Try modifying your query to improve the performance or contact your RT admin.',
+);
+
+=head1 UserMessages
+
+Returns a hash with keys of message codes and values with corresponding user
+messages.
+
+To add messages, create entries in C<%USER_MESSAGES> with an appropriate
+message code as the key.
+
+To trigger display of that message, add an entry to notes, prefixed with
+C<Message:>, like:
+
+    if ( $something_happened ) {
+        $HTML::Mason::Commands::m->notes('Message:SQLTimeout' => 1 );
+    }
+
+For the web UI, C<Elements/Footer> will pick that up and display the message
+to the user in the browser.
+
+=cut
+
+sub UserMessages {
+    my $self = shift;
+    # Return a copy to avoid it from changing by accident.
+    return { %USER_MESSAGES };
+}
+
+=head2 CurrentUserCanSee TYPE, OBJECT
+
+Return false if TYPE is "Transaction" and current user is not "SuperUser",
+returns true otherwise.
+
+=cut
+
+sub CurrentUserCanSee {
+    my $self = shift;
+    my ( $what, $txn ) = @_;
+    return 1 unless ( $what // '' ) eq 'Transaction';
+    return $self->CurrentUserHasRight('SuperUser') ? 1 : 0;
+}
+
+=head2 PrincipalId
+
+Returns system user's PrincipalId
+
+=cut
+
+sub PrincipalId {
+    my $self = shift;
+    return $self->Id;
+}
+
 RT::Base->_ImportOverlays();
 
 1;
