@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -71,6 +71,8 @@ use strict;
 use warnings;
 
 use base 'RT::Record';
+use Role::Basic 'with';
+with "RT::Record::Role::LookupType";
 
 use RT::Queue;
 
@@ -88,7 +90,8 @@ sub _Accessible {
         Description   => 'read/write',
         Type          => 'read/write',    #Type is one of Perl or Simple
         Content       => 'read/write',
-        Queue         => 'read/write',
+        ObjectId      => 'read/write',
+        LookupType    => 'read/write',
         Creator       => 'read/auto',
         Created       => 'read/auto',
         LastUpdatedBy => 'read/auto',
@@ -105,17 +108,18 @@ sub _Set {
         @_,
     );
     
-    unless ( $self->CurrentUserHasQueueRight('ModifyTemplate') ) {
+    unless ( $self->CurrentUserHasObjectRight('ModifyTemplate') ) {
         return ( 0, $self->loc('Permission Denied') );
     }
 
     if (exists $args{Value}) {
-        if ($args{Field} eq 'Queue') {
+        if ($args{Field} eq 'ObjectId') {
             if ($args{Value}) {
-                # moving to another queue
-                my $queue = RT::Queue->new( $self->CurrentUser );
-                $queue->Load($args{Value});
-                unless ($queue->Id and $queue->CurrentUserHasRight('ModifyTemplate')) {
+                # moving to another object
+                my $class = $self->RecordClassFromLookupType( $self->LookupType );
+                my $object = $class->new( $self->CurrentUser );
+                $class->Load($args{Value});
+                unless ($object->Id and $object->CurrentUserHasRight('ModifyTemplate')) {
                     return ( 0, $self->loc('Permission Denied') );
                 }
             } else {
@@ -154,7 +158,7 @@ Load a template, either by number or by name.
 Note that loading templates by name using this method B<is
 ambiguous>. Several queues may have template with the same name
 and as well global template with the same name may exist.
-Use L</LoadByName>, L</LoadGlobalTemplate> or L<LoadQueueTemplate> to get
+Use L</LoadByName>, L</LoadGlobalTemplate> or L<LoadObjectTemplate> to get
 precise result.
 
 =cut
@@ -172,19 +176,22 @@ sub Load {
 
 =head2 LoadByName
 
-Takes Name and Queue arguments. Tries to load queue specific template
-first, then global. If Queue argument is omitted then global template
-is tried, not template with the name in any queue.
+Takes Name, LookupType, and ObjectId arguments. Tries to load object specific template
+first, then global. If ObjectId argument is omitted then global template
+is tried, not template with the name in any object.
 
 =cut
 
 sub LoadByName {
     my $self = shift;
     my %args = (
-        Queue => undef,
-        Name  => undef,
+        ObjectId   => undef,
+        Name       => undef,
+        LookupType => RT::Ticket->CustomFieldLookupType,
         @_
     );
+
+    # Backwards compatibility
     my $queue = $args{'Queue'};
     if ( blessed $queue ) {
         $queue = $queue->id;
@@ -194,53 +201,80 @@ sub LoadByName {
         $queue = $tmp->id;
     }
 
-    return $self->LoadGlobalTemplate( $args{'Name'} ) unless $queue;
+    $args{ObjectId} //= $queue;
 
-    $self->LoadQueueTemplate( Queue => $queue, Name => $args{'Name'} );
+    if ( $args{ObjectId} ) {
+        $self->LoadObjectTemplate(
+            ObjectId   => $args{ObjectId},
+            Name       => $args{'Name'},
+            LookupType => $args{LookupType},
+        );
+        return $self->id if $self->id;
+    }
+
+    $self->LoadGlobalTemplate( $args{'Name'}, $args{LookupType} );
     return $self->id if $self->id;
-    return $self->LoadGlobalTemplate( $args{'Name'} );
 }
 
-=head2 LoadGlobalTemplate NAME
+=head2 LoadGlobalTemplate NAME LOOKUPTYPE
 
-Load the global template with the name NAME
+Load the global template with the name NAME and LookupType LOOKUPTYPE.
 
 =cut
 
 sub LoadGlobalTemplate {
     my $self = shift;
     my $name = shift;
+    my $type = shift || RT::Ticket->CustomFieldLookupType;
 
-    return ( $self->LoadQueueTemplate( Queue => 0, Name => $name ) );
+    return ( $self->LoadObjectTemplate( ObjectId => 0, Name => $name, LookupType => $type ) );
 }
 
-=head2 LoadQueueTemplate (Queue => QUEUEID, Name => NAME)
+=head2 LoadObjectTemplate (ObjectId => QUEUEID, Name => NAME, LookupType => LOOKUPTYPE)
 
-Loads the Queue template named NAME for Queue QUEUE.
+Loads the Object template named NAME for Object QUEUE.
 
 Note that this method doesn't load a global template with the same name
-if template in the queue doesn't exist. Use L</LoadByName>.
+if template in the object doesn't exist. Use L</LoadByName>.
 
 =cut
 
-sub LoadQueueTemplate {
+sub LoadObjectTemplate {
     my $self = shift;
     my %args = (
-        Queue => undef,
-        Name  => undef,
+        ObjectId   => undef,
+        Name       => undef,
+        LookupType => RT::Ticket->CustomFieldLookupType,
         @_
     );
 
-    return ( $self->LoadByCols( Name => $args{'Name'}, Queue => $args{'Queue'} ) );
+    return (
+        $self->LoadByCols(
+            Name       => $args{'Name'},
+            ObjectId   => $args{'ObjectId'},
+            LookupType => $args{'LookupType'},
+        )
+    );
+}
 
+sub LoadQueueTemplate {
+    my $self = shift;
+    RT->Deprecated(
+        Message => 'LoadQueueTemplate is deprecated',
+        Instead => 'LoadObjectTemplate',
+        Remove  => 6.2,
+    );
+    my %args = @_;
+    $args{ObjectId} //= delete $args{Queue};
+    return $self->LoadObjectTemplate(%args);
 }
 
 =head2 Create
 
-Takes a paramhash of Content, Queue, Name and Description.
+Takes a paramhash of Content, Object, LookupType, Name, and Description.
 Name should be a unique string identifying this Template.
 Description and Content should be the template's title and content.
-Queue should be 0 for a global template and the queue # for a queue-specific 
+ObjectId should be 0 for a global template and the object id for a object-specific 
 template.
 
 Returns the Template's id # if the create was successful. Returns undef for
@@ -252,31 +286,36 @@ sub Create {
     my $self = shift;
     my %args = (
         Content     => undef,
-        Queue       => 0,
+        ObjectId    => undef,
         Description => '[no description]',
         Type        => 'Perl',
         Name        => undef,
+        LookupType  => 'RT::Queue-RT::Ticket',
         @_
     );
 
+    # Backwards compatibility
+    $args{ObjectId} //= $args{Queue};
+
     if ( $args{Type} eq 'Perl' && !$self->CurrentUser->HasRight(Right => 'ExecuteCode', Object => $RT::System) ) {
         return ( undef, $self->loc('Permission Denied') );
     }
 
-    unless ( $args{'Queue'} ) {
+    unless ( $args{'ObjectId'} ) {
         unless ( $self->CurrentUser->HasRight(Right =>'ModifyTemplate', Object => $RT::System) ) {
             return ( undef, $self->loc('Permission Denied') );
         }
-        $args{'Queue'} = 0;
+        $args{'ObjectId'} = 0;
     }
     else {
-        my $QueueObj = RT::Queue->new( $self->CurrentUser );
-        $QueueObj->Load( $args{'Queue'} ) || return ( undef, $self->loc('Invalid queue') );
+        my $class = $self->RecordClassFromLookupType( $args{'LookupType'} );
+        my $object = $class->new( $self->CurrentUser );
+        $object->Load( $args{'ObjectId'} ) || return ( undef, $self->loc('Invalid ObjectId') );
     
-        unless ( $QueueObj->CurrentUserHasRight('ModifyTemplate') ) {
+        unless ( $object->CurrentUserHasRight('ModifyTemplate') ) {
             return ( undef, $self->loc('Permission Denied') );
         }
-        $args{'Queue'} = $QueueObj->Id;
+        $args{'ObjectId'} = $object->Id;
     }
 
     return ( undef, $self->loc('Name is required') )
@@ -284,17 +323,18 @@ sub Create {
 
     {
         my $tmp = $self->new( RT->SystemUser );
-        $tmp->LoadByCols( Name => $args{'Name'}, Queue => $args{'Queue'} );
+        $tmp->LoadByCols( Name => $args{'Name'}, ObjectId => $args{'ObjectId'}, LookupType => $args{'LookupType'} );
         return ( undef, $self->loc('A Template with that name already exists') )
             if $tmp->id;
     }
 
     my ( $result, $msg ) = $self->SUPER::Create(
         Content     => $args{'Content'},
-        Queue       => $args{'Queue'},
+        ObjectId    => $args{'ObjectId'},
         Description => $args{'Description'},
         Name        => $args{'Name'},
         Type        => $args{'Type'},
+        LookupType  => $args{'LookupType'},
     );
 
     if ( wantarray ) {
@@ -314,7 +354,7 @@ Delete this template.
 sub Delete {
     my $self = shift;
 
-    unless ( $self->CurrentUserHasQueueRight('ModifyTemplate') ) {
+    unless ( $self->CurrentUserHasObjectRight('ModifyTemplate') ) {
         return ( 0, $self->loc('Permission Denied') );
     }
 
@@ -327,8 +367,8 @@ sub Delete {
 
 =head2 UsedBy
 
-Returns L<RT::Scrips> limitted to scrips that use this template. Takes
-into account that template can be overriden in a queue.
+Returns L<RT::Scrips> limited to scrips that use this template. Takes
+into account that template can be overridden in a queue.
 
 =cut
 
@@ -356,17 +396,17 @@ sub IsEmpty {
 
 =head2 IsOverride
 
-Returns true if it's queue specific template and there is global
+Returns true if it's object specific template and there is global
 template with the same name.
 
 =cut
 
 sub IsOverride {
     my $self = shift;
-    return 0 unless $self->Queue;
+    return 0 unless $self->ObjectId;
 
     my $template = RT::Template->new( $self->CurrentUser );
-    $template->LoadGlobalTemplate( $self->Name );
+    $template->LoadGlobalTemplate( $self->Name, $self->LookupType );
     return $template->id;
 }
 
@@ -406,6 +446,7 @@ sub Parse {
     my $self = shift;
     my ($rv, $msg);
 
+    delete $self->{_AddedAttachments};
 
     if (not $self->IsEmpty and $self->Content =~ m{^Content-Type:\s+text/html\b}im) {
         local $RT::Transaction::PreferredContentType = 'text/html';
@@ -417,8 +458,47 @@ sub Parse {
 
     return ($rv, $msg) unless $rv;
 
+    my %args = @_;
     my $mime_type   = $self->MIMEObj->mime_type;
-    if (defined $mime_type and $mime_type eq 'text/html') {
+    if ( defined $mime_type and $mime_type eq 'text/html' and $args{TransactionObj} ) {
+        if ( my $content_obj = $args{TransactionObj}->ContentObj( Type => 'text/html' ) ) {
+            if ( my $related_part = $content_obj->Closest("multipart/related") ) {
+                my $body = Encode::decode( "UTF-8", $self->MIMEObj->bodyhandle->as_string );
+                my ( @attachments, %added );
+                require HTML::RewriteAttributes::Resources;
+                HTML::RewriteAttributes::Resources->rewrite(
+                    $body,
+                    sub {
+                        my $cid  = shift;
+                        my %meta = @_;
+                        return $cid unless lc $meta{tag} eq 'img' && lc $meta{attr} eq 'src' && $cid =~ s/^cid://i;
+
+                        for my $attach ( @{$related_part->Children->ItemsArrayRef } ) {
+                            if ( ( $attach->GetHeader('Content-ID') || '' ) =~ /^(<)?\Q$cid\E(?(1)>)$/ ) {
+                                push @attachments, $attach unless $added{$attach->Id}++;
+                            }
+                        }
+
+                        return "cid:$cid";
+                    }
+                );
+
+                if ( @attachments ) {
+                    $self->MIMEObj->make_multipart('related');
+                    # RFC2387 3.1 says that "type" must be specified
+                    $self->MIMEObj->head->mime_attr('Content-type.type' => 'text/html');
+                    for my $attach ( @attachments ) {
+                        $self->MIMEObj->attach(
+                            Type        => $attach->ContentType,
+                            Disposition => $attach->GetHeader('Content-Disposition'),
+                            Id          => $attach->GetHeader('Content-ID'),
+                            Data        => $attach->OriginalContent,
+                        );
+                    }
+                    $self->{_AddedAttachments} = { map { $_->Id => 1 } @attachments };
+                }
+            }
+        }
         $self->_DowngradeFromHTML(@_);
     }
 
@@ -474,7 +554,10 @@ sub _ParseContent {
     my $self = shift;
     my %args = (
         Argument       => undef,
+        Object         => undef,
         TicketObj      => undef,
+        AssetObj       => undef,
+        ArticleObj     => undef,
         TransactionObj => undef,
         @_
     );
@@ -489,13 +572,15 @@ sub _ParseContent {
 
     my $content = $self->SUPER::_Value('Content');
 
-    $args{'Ticket'} = delete $args{'TicketObj'} if $args{'TicketObj'};
+    for my $field ( qw/Ticket Asset Article/ ) {
+        $args{$field} = delete $args{"${field}Obj"} if $args{"${field}Obj"};
+    }
     $args{'Transaction'} = delete $args{'TransactionObj'} if $args{'TransactionObj'};
     $args{'Requestor'} = eval { $args{'Ticket'}->Requestors->UserMembersObj->First->Name }
         if $args{'Ticket'};
     $args{'rtname'}    = RT->Config->Get('rtname');
-    if ( $args{'Ticket'} ) {
-        my $t = $args{'Ticket'}; # avoid memory leak
+    if ( $args{'Ticket'} || $args{'Asset'} || $args{'Article'} ) {
+        my $t = $args{'Ticket'} || $args{'Asset'} || $args{'Article'}; # avoid memory leak
         $args{'loc'} = sub { $t->loc(@_) };
     } else {
         $args{'loc'} = sub { $self->loc(@_) };
@@ -635,6 +720,27 @@ sub _MassageSimpleTemplateArgs {
 
     my $template_args = $args{TemplateArgs};
 
+    if (my $ticket = $template_args->{Ticket}) {
+        for my $column (qw/Id Subject Description Type InitialPriority FinalPriority Priority TimeEstimated TimeWorked Status TimeLeft Told Starts Started Due Resolved RequestorAddresses AdminCcAddresses CcAddresses/) {
+            $template_args->{"Ticket".$column} = $ticket->$column;
+        }
+
+        $template_args->{"TicketQueueId"}   = $ticket->Queue;
+        $template_args->{"TicketQueueName"} = $ticket->QueueObj->Name;
+
+        $template_args->{"TicketOwnerId"}    = $ticket->Owner;
+        $template_args->{"TicketOwnerName"}  = $ticket->OwnerObj->Name;
+        $template_args->{"TicketOwnerEmailAddress"} = $ticket->OwnerObj->EmailAddress;
+
+        my $cfs = $ticket->CustomFields;
+        while (my $cf = $cfs->Next) {
+            my $simple = $cf->Name;
+            $simple =~ s/\W//g;
+            $template_args->{"TicketCF" . $simple}
+                = $ticket->CustomFieldValuesAsString($cf->Name);
+        }
+    }
+
     if (my $ticket = $template_args->{Ticket}) {
         for my $column (qw/Id Subject Type InitialPriority FinalPriority Priority TimeEstimated TimeWorked Status TimeLeft Told Starts Started Due Resolved RequestorAddresses AdminCcAddresses CcAddresses/) {
             $template_args->{"Ticket".$column} = $ticket->$column;
@@ -656,6 +762,38 @@ sub _MassageSimpleTemplateArgs {
         }
     }
 
+    if ( my $asset = $template_args->{Asset} ) {
+        for my $column (qw/Id Name Description Status/) {
+            $template_args->{ "Asset" . $column } = $asset->$column;
+        }
+
+        $template_args->{"AssetCatalogId"}   = $asset->Catalog;
+        $template_args->{"AssetCatalogName"} = $asset->CatalogObj->Name;
+
+        my $cfs = $asset->CustomFields;
+        while ( my $cf = $cfs->Next ) {
+            my $simple = $cf->Name;
+            $simple =~ s/\W//g;
+            $template_args->{ "AssetCF" . $simple } = $asset->CustomFieldValuesAsString( $cf->Name );
+        }
+    }
+
+    if ( my $article = $template_args->{Article} ) {
+        for my $column (qw/Id Name Summary/) {
+            $template_args->{ "Article" . $column } = $article->$column;
+        }
+
+        $template_args->{"ArticleClassId"}   = $article->Class;
+        $template_args->{"ArticleClassName"} = $article->ClassObj->Name;
+
+        my $cfs = $article->CustomFields;
+        while ( my $cf = $cfs->Next ) {
+            my $simple = $cf->Name;
+            $simple =~ s/\W//g;
+            $template_args->{ "AssetCF" . $simple } = $article->CustomFieldValuesAsString( $cf->Name );
+        }
+    }
+
     if (my $txn = $template_args->{Transaction}) {
         for my $column (qw/Id TimeTaken Type Field OldValue NewValue Data Content Subject Description BriefDescription/) {
             $template_args->{"Transaction".$column} = $txn->$column;
@@ -675,7 +813,8 @@ sub _DowngradeFromHTML {
     my $self = shift;
     my $orig_entity = $self->MIMEObj;
 
-    my $new_entity = $orig_entity->dup; # this will fail badly if we go away from InCore parsing
+    my $html_entity = $orig_entity->is_multipart ? $orig_entity->parts(0) : $orig_entity;
+    my $new_entity = $html_entity->dup; # this will fail badly if we go away from InCore parsing
 
     # We're going to make this multipart/alternative below, so clear out the Subject
     # header copied from the original when we dup'd above.
@@ -689,8 +828,8 @@ sub _DowngradeFromHTML {
     $new_entity->head->mime_attr( "Content-Type" => 'text/plain' );
     $new_entity->head->mime_attr( "Content-Type.charset" => 'utf-8' );
 
-    $orig_entity->head->mime_attr( "Content-Type" => 'text/html' );
-    $orig_entity->head->mime_attr( "Content-Type.charset" => 'utf-8' );
+    $html_entity->head->mime_attr( "Content-Type" => 'text/html' );
+    $html_entity->head->mime_attr( "Content-Type.charset" => 'utf-8' );
 
     my $body = $new_entity->bodyhandle->as_string;
     $body = Encode::decode( "UTF-8", $body );
@@ -707,26 +846,36 @@ sub _DowngradeFromHTML {
     return;
 }
 
-=head2 CurrentUserHasQueueRight
+=head2 CurrentUserHasObjectRight
 
-Helper function to call the template's queue's CurrentUserHasQueueRight with the passed in args.
+Helper function to call the template's object's CurrentUserHasRight with the passed in args.
 
 =cut
 
+sub CurrentUserHasObjectRight {
+    my $self = shift;
+    return ( $self->Object->CurrentUserHasRight(@_) );
+}
+
 sub CurrentUserHasQueueRight {
     my $self = shift;
-    return ( $self->QueueObj->CurrentUserHasRight(@_) );
+    RT->Deprecated(
+        Message => 'CurrentUserHasQueueRight is deprecated',
+        Instead => 'CurrentUserHasObjectRight',
+        Remove  => 6.2,
+    );
+    return $self->CurrentUserHasObjectRight(@_);
 }
 
-=head2 SetQueue
+=head2 SetObjectId
 
-Changing queue is not implemented.
+Changing ObjectId is not implemented.
 
 =cut
 
-sub SetQueue {
+sub SetObjectId {
     my $self = shift;
-    return ( undef, $self->loc('Changing queue is not implemented') );
+    return ( undef, $self->loc('Changing ObjectId is not implemented') );
 }
 
 =head2 SetName
@@ -746,7 +895,7 @@ sub SetName {
         if lc($self->Name) eq lc($value);
 
     my $tmp = $self->new( RT->SystemUser );
-    $tmp->LoadByCols( Name => $value, Queue => $self->Queue );
+    $tmp->LoadByCols( Name => $value, ObjectId => $self->ObjectId, LookupType => $self->LookupType );
     return ( undef, $self->loc('A Template with that name already exists') )
         if $tmp->id;
 
@@ -860,12 +1009,14 @@ sub CompileCheck {
 =cut
 
 sub CurrentUserCanRead {
-    my $self =shift;
+    my $self = shift;
+    return 1 if $self->CurrentUser->Id == RT->SystemUser->id;
 
-    if ($self->__Value('Queue')) {
-        my $queue = RT::Queue->new( RT->SystemUser );
-        $queue->Load( $self->__Value('Queue'));
-        return 1 if $self->CurrentUser->HasRight( Right => 'ShowTemplate', Object => $queue );
+    if ($self->__Value('ObjectId')) {
+        my $class = $self->RecordClassFromLookupType( $self->__Value('LookupType') );
+        my $object = $class->new( RT->SystemUser );
+        $object->Load( $self->__Value('ObjectId'));
+        return 1 if $self->CurrentUser->HasRight( Right => 'ShowTemplate', Object => $object );
     } else {
         return 1 if $self->CurrentUser->HasRight( Right => 'ShowGlobalTemplates', Object => $RT::System );
         return 1 if $self->CurrentUser->HasRight( Right => 'ShowTemplate',        Object => $RT::System );
@@ -892,36 +1043,36 @@ Returns the current value of id.
 =cut
 
 
-=head2 Queue
-
-Returns the current value of Queue.
-(In the database, Queue is stored as int(11).)
-
-
-
-=head2 SetQueue VALUE
-
-
-Set Queue to VALUE.
-Returns (1, 'Status message') on success and (0, 'Error Message') on failure.
-(In the database, Queue will be stored as a int(11).)
+=head2 ObjectId
 
+Returns the current value of ObjectId.
+(In the database, ObjectId is stored as int(11).)
 
 =cut
 
 
-=head2 QueueObj
-
-Returns the Queue Object which has the id returned by Queue
+=head2 Object
 
+Returns the Object which has the id returned by ObjectId
 
 =cut
 
+sub Object {
+    my $self = shift;
+    my $class = $self->RecordClassFromLookupType( $self->LookupType );
+    my $object = $class->new($self->CurrentUser);
+    $object->Load($self->__Value('ObjectId'));
+    return $object;
+}
+
 sub QueueObj {
     my $self = shift;
-    my $Queue =  RT::Queue->new($self->CurrentUser);
-    $Queue->Load($self->__Value('Queue'));
-    return($Queue);
+    RT->Deprecated(
+        Message => 'QueueObj is deprecated',
+        Instead => 'Object',
+        Remove  => 6.2,
+    );
+    return $self->Object;
 }
 
 =head2 Name
@@ -995,6 +1146,12 @@ Returns (1, 'Status message') on success and (0, 'Error Message') on failure.
 
 =cut
 
+=head2 LookupType
+
+Returns the current value of LookupType.
+(In the database, LookupType is stored as varchar(255).)
+
+=cut
 
 =head2 LastUpdated
 
@@ -1038,7 +1195,7 @@ sub _CoreAccessible {
 
         id =>
                 {read => 1, sql_type => 4, length => 11,  is_blob => 0,  is_numeric => 1,  type => 'int(11)', default => ''},
-        Queue =>
+        ObjectId =>
                 {read => 1, write => 1, sql_type => 4, length => 11,  is_blob => 0,  is_numeric => 1,  type => 'int(11)', default => '0'},
         Name =>
                 {read => 1, write => 1, sql_type => 12, length => 200,  is_blob => 0,  is_numeric => 0,  type => 'varchar(200)', default => ''},
@@ -1048,6 +1205,8 @@ sub _CoreAccessible {
                 {read => 1, write => 1, sql_type => 12, length => 16,  is_blob => 0,  is_numeric => 0,  type => 'varchar(16)', default => ''},
         Content =>
                 {read => 1, write => 1, sql_type => -4, length => 0,  is_blob => 1,  is_numeric => 0,  type => 'text', default => ''},
+        LookupType =>
+                {read => 1, write => 1, sql_type => 12, length => 255,  is_blob => 0,  is_numeric => 0,  type => 'varchar(255)', default => ''},
         LastUpdated =>
                 {read => 1, auto => 1, sql_type => 11, length => 0,  is_blob => 0,  is_numeric => 0,  type => 'datetime', default => ''},
         LastUpdatedBy =>
@@ -1066,7 +1225,7 @@ sub FindDependencies {
 
     $self->SUPER::FindDependencies($walker, $deps);
 
-    $deps->Add( out => $self->QueueObj ) if $self->QueueObj->Id;
+    $deps->Add( out => $self->Object ) if $self->Object->Id;
 }
 
 sub __DependsOn {
@@ -1099,10 +1258,14 @@ sub PreInflate {
     $class->SUPER::PreInflate( $importer, $uid, $data );
 
     my $obj = RT::Template->new( RT->SystemUser );
-    if ($data->{Queue} == 0) {
-        $obj->LoadGlobalTemplate( $data->{Name} );
+    if ($data->{ObjectId} == 0) {
+        $obj->LoadGlobalTemplate( $data->{Name}, $data->{LookupType} || 'RT::Queue-RT::Ticket' );
     } else {
-        $obj->LoadQueueTemplate( Queue => $data->{Queue}, Name => $data->{Name} );
+        $obj->LoadObjectTemplate(
+            ObjectId   => $data->{ObjectId},
+            Name       => $data->{Name},
+            LookupType => $data->{LookupType} || 'RT::Queue-RT::Ticket',
+        );
     }
 
     if ($obj->Id) {
