@@ -7,7 +7,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -59,7 +59,7 @@ use base qw(RT::Test);
 use File::Temp qw(tempdir);
 use IPC::Run3 'run3';
 use File::Copy;
-use 5.010;
+use 5.26.3;
 
 our @EXPORT =
   qw(create_a_ticket update_ticket cleanup_headers set_queue_crypt_options 
@@ -75,7 +75,7 @@ sub import {
     RT::Test::plan( skip_all => 'ENV SKIP_GPG_TESTS is set to true.' )
       if $ENV{'SKIP_GPG_TESTS'};
     RT::Test::plan( skip_all => 'GnuPG required.' )
-      unless GnuPG::Interface->require;
+      unless RT::StaticUtil::RequireModule("GnuPG::Interface");
     RT::Test::plan( skip_all => 'gpg executable is required.' )
       unless RT::Test->find_executable('gpg');
 
@@ -385,14 +385,14 @@ sub create_and_test_outgoing_emails {
 }
 
 sub gnupg_version {
-    GnuPG::Interface->require or return;
+    RT::StaticUtil::RequireModule("GnuPG::Interface") or return;
     require version;
     state $gnupg_version = version->parse(GnuPG::Interface->new->version);
 }
 
 sub new_homedir {
     my $source = shift;
-    return if $ENV{'SKIP_GPG_TESTS'} || !RT::Test->find_executable('gpg') || !GnuPG::Interface->require;
+    return if $ENV{'SKIP_GPG_TESTS'} || !RT::Test->find_executable('gpg') || !RT::StaticUtil::RequireModule("GnuPG::Interface");
     my $dir = tempdir();
 
     if ($source) {
@@ -419,4 +419,6 @@ END {
     diag "RT::Test::GnuPG is deprecated; please use RT::Test::Crypt GnuPG => 1 instead";
 }
 
+RT::Base->_ImportOverlays();
+
 1;
