@@ -7,7 +7,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -53,7 +53,7 @@
 
 use strict;
 use warnings;
-use 5.010;
+use 5.26.3;
 
 package RT::Test::SMIME;
 
@@ -169,4 +169,6 @@ END {
     diag('RT::Test::SMIME is deprecated; please use RT::Test::Crypt SMIME => 1 instead');
 }
 
+RT::Base->_ImportOverlays();
+
 1;
