@@ -56,6 +56,7 @@ use MIME::Base64 qw//;
 use Encode 'encode_utf8';
 use Storable 'thaw';
 use HTTP::Status qw();
+use Mojo::DOM;
 
 BEGIN { require RT::Test; }
 require Test::More;
@@ -318,11 +319,11 @@ sub ticket_status {
     my $id = shift;
     
     $self->display_ticket( $id);
-    my ($got) = ($self->content =~ m{Status:\s*</div>\s*<div.*?>\s*<span.*?>\s*([\w ]+?)\s*</span>}ism);
-    unless ( $got ) {
-        Test::More::diag("Error: couldn't find status value on the page, may be regexp problem");
+    my $status = $self->dom->at('div.status div.rt-value .rt-value.current-value');
+    unless ( $status ) {
+        Test::More::diag("Error: couldn't find status value on the page");
     }
-    return $got;
+    return $status->text;
 }
 
 sub ticket_status_is {
@@ -449,10 +450,23 @@ sub dom {
     my $self = shift;
     Carp::croak("Can not get DOM, not HTML repsone")
         unless $self->is_html;
-    require Mojo::DOM;
     return Mojo::DOM->new( $self->content );
 }
 
+sub update_html {
+    my $self = shift;
+    my $html = shift;
+    my $dom = Mojo::DOM->new($html);
+    if ( my $prefix_dom = $dom->at('[data-name-prefix]') ) {
+        my $prefix = $prefix_dom->attr('data-name-prefix');
+        for my $input ( $prefix_dom->find('input, select, textarea')->each ) {
+            $input->attr( name => $prefix . $input->attr('name') );
+        }
+        $html = $dom->content;
+    }
+    return $self->SUPER::update_html($html);
+}
+
 # override content_* and text_* methods in Test::Mech to dump the content
 # on failure, to speed investigation
 for my $method_name (qw/
