@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -72,7 +72,7 @@ use warnings;
 use base 'RT::SearchBuilder';
 
 use RT::Transaction;
-use 5.010;
+use 5.26.3;
 
 sub Table { 'Transactions'}
 
@@ -185,6 +185,9 @@ our %FIELD_METADATA = (
     Data          => ['STRING'],                 #loc_left_pair
     Created       => [ 'DATE' => 'Created' ],    #loc_left_pair
 
+    TimeWorker     => [ 'ENUM' => 'User' ],              #loc_left_pair
+    TimeWorkedDate => [ 'DATE' => 'TimeWorkedDate' ],    #loc_left_pair
+
     Content     => ['ATTACHCONTENT'],            #loc_left_pair
     ContentType => ['ATTACHFIELD'],              #loc_left_pair
     Filename    => ['ATTACHFIELD'],              #loc_left_pair
@@ -254,6 +257,23 @@ sub SortFields {
     return (@SORTFIELDS);
 }
 
+=head2 SplitFields
+
+Returns the list of fields that are supposed to be split into individual
+subqueries and then combined later.
+
+If fulltext search is enabled and indexed, it returns C<Content>, otherwise
+it returns an empty list.
+
+=cut
+
+sub SplitFields {
+    my $self = shift;
+    my $config = RT->Config->Get('FullTextSearch') || {};
+    return 'Content' if $config->{Enable} && $config->{Indexed};
+    return;
+}
+
 =head1 Limit Helper Routines
 
 These routines are the targets of a dispatch table depending on the
@@ -405,7 +425,16 @@ sub _DateLimit {
     my $date = RT::Date->new( $sb->CurrentUser );
     $date->Set( Format => 'unknown', Value => $value );
 
-    if ( $op eq "=" ) {
+    if ( $meta->[1] eq 'TimeWorkedDate' ) {
+        $sb->Limit(
+            FUNCTION => $sb->NotSetDateToNullFunction,
+            FIELD    => $meta->[1],
+            OPERATOR => $op,
+            VALUE    => $date->Date( Timezone => 'user' ),
+            %rest,
+        );
+    }
+    elsif ( $op eq "=" ) {
 
         # if we're specifying =, that means we want everything on a
         # particular single day.  in the database, we need to check for >
@@ -768,7 +797,7 @@ sub _AttachContentLimit {
                 QUOTEVALUE  => 0,
             );
         }
-        elsif ( $db_type eq 'mysql' and not $config->{Sphinx}) {
+        elsif ( $db_type eq 'mysql' ) {
             my $dbh = $RT::Handle->dbh;
             $self->Limit(
                 %rest,
@@ -790,23 +819,6 @@ sub _AttachContentLimit {
                 QUOTEVALUE      => 0,
             );
         }
-        elsif ( $db_type eq 'mysql' ) {
-            # This is a special character.  Note that \ does not escape
-            # itself (in Sphinx 2.1.0, at least), so 'foo\;bar' becoming
-            # 'foo\\;bar' is not a vulnerability, and is still parsed as
-            # "foo, \, ;, then bar".  Happily, the default mode is
-            # "all", meaning that boolean operators are not special.
-            $value =~ s/;/\\;/g;
-
-            my $max = $config->{'MaxMatches'};
-            $self->Limit(
-                %rest,
-                ALIAS       => $alias,
-                FIELD       => 'query',
-                OPERATOR    => '=',
-                VALUE       => "$value;limit=$max;maxmatches=$max",
-            );
-        }
     } else {
         # This is the main difference from ticket content search.
         # For transaction searches, it probably worths keeping emails.
@@ -818,7 +830,7 @@ sub _AttachContentLimit {
         # );
 
         $self->Limit(
-            ENTRYAGGREGATOR => 'AND',
+            %rest,
             ALIAS           => $self->{_sql_aliases}{attach},
             FIELD           => $field,
             OPERATOR        => $op,
@@ -1180,6 +1192,12 @@ sub FromSQL {
         return (0, $error);
     }
 
+    if ( !$self->{_no_split} ) {
+        if ( my $split_query = $self->_SplitQuery($query) ) {
+            $self->{_split_query} = $split_query;
+        }
+    }
+
     # set SB's dirty flag
     $self->{'must_redo_search'} = 1;
 
