@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2013 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -54,7 +54,7 @@ use base 'RT::URI::fsck_com_rt';
 
 =head1 NAME
 
-RT::URI::t - aliad for RT::URI::fsck_com_rt that supports 't:12345' URIs
+RT::URI::t - alias for RT::URI::fsck_com_rt that supports 't:12345' URIs
 
 =head2 ParseURI URI
 
@@ -74,4 +74,6 @@ sub ParseURI {
     return $self->SUPER::ParseURI($uri);
 }
 
+RT::Base->_ImportOverlays();
+
 1;
