@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -69,8 +69,11 @@ use strict;
 use warnings;
 
 use Scalar::Util qw(blessed);
+use List::Util qw(reduce);
 
 use base 'RT::Record';
+use Role::Basic 'with';
+with "RT::Record::Role::Principal";
 
 sub Table {'Users'}
 
@@ -103,6 +106,8 @@ sub _OverlayAccessible {
           City                  => { public => 1 },                 # loc_left_pair
           Country               => { public => 1 },                 # loc_left_pair
           Timezone              => { public => 1 },                 # loc_left_pair
+          Image                 => { public => 1 },                 # loc_left_pair
+          ImageContentType      => { public => 1 },                 # loc_left_pair
     }
 }
 
@@ -829,6 +834,20 @@ sub EmailFrequency {
     return '';
 }
 
+=head2 URI
+
+Returns this user's URI
+
+=cut
+
+sub URI {
+    my $self = shift;
+
+    require RT::URI::user;
+    my $uri = RT::URI::user->new($self->CurrentUser);
+    return $uri->URIForObject($self);
+}
+
 =head2 CanonicalizeEmailAddress ADDRESS
 
 CanonicalizeEmailAddress converts email addresses into canonical form.
@@ -878,7 +897,7 @@ sub CanonicalizeUserInfo {
 
 =head2 CanonicalizeUserInfoFromExternalAuth
 
-Convert an ldap entry in to fields that can be used by RT as specified by the
+Convert an LDAP entry in to fields that can be used by RT as specified by the
 C<attr_map> configuration in the C<$ExternalSettings> variable for
 L<RT::Authen::ExternalAuth>.
 
@@ -1028,7 +1047,7 @@ sub SetRandomPassword {
 =head3 ResetPassword
 
 Returns status, [ERROR or new password].  Resets this user's password to
-a randomly generated pronouncable password and emails them, using a
+a randomly generated pronounceable password and emails them, using a
 global template called "PasswordChange".
 
 This function is currently unused in the UI, but available for local scripts.
@@ -1345,7 +1364,7 @@ sub CurrentUserRequireToSetPassword {
 
 Returns an authentication string associated with the user. This
 string can be used to generate passwordless URLs to integrate
-RT with services and programms like callendar managers, rss
+RT with services and programs like calendar managers, RSS
 readers and other.
 
 =cut
@@ -1459,49 +1478,7 @@ sub Disabled {
     return $self->PrincipalObj->Disabled(@_);
 }
 
-=head2 PrincipalObj
-
-Returns the principal object for this user. returns an empty RT::Principal
-if there's no principal object matching this user.
-The response is cached. PrincipalObj should never ever change.
-
-=cut
-
-sub PrincipalObj {
-    my $self = shift;
-
-    unless ( $self->id ) {
-        $RT::Logger->error("Couldn't get principal for an empty user");
-        return undef;
-    }
-
-    if ( !$self->{_principal_obj} ) {
-
-        my $obj = RT::Principal->new( $self->CurrentUser );
-        $obj->LoadById( $self->id );
-        if (! $obj->id ) {
-            $RT::Logger->crit( 'No principal for user #' . $self->id );
-            return undef;
-        } elsif ( $obj->PrincipalType ne 'User' ) {
-            $RT::Logger->crit(   'User #' . $self->id . ' has principal of ' . $obj->PrincipalType . ' type' );
-            return undef;
-        }
-        $self->{_principal_obj} = $obj;
-    }
-    return $self->{_principal_obj};
-}
-
-
-=head2 PrincipalId
-
-Returns this user's PrincipalId
-
-=cut
-
-sub PrincipalId {
-    my $self = shift;
-    return $self->Id;
-}
+sub PrincipalField { 'id' }
 
 =head2 HasGroupRight
 
@@ -1547,20 +1524,24 @@ sub HasGroupRight {
     return ($retval);
 }
 
-=head2 OwnGroups
+=head2 OwnGroups Recursively => 1|0
 
 Returns a group collection object containing the groups of which this
-user is a member.
+user is a member, recursively by default.
 
 =cut
 
 sub OwnGroups {
     my $self = shift;
+    my %args = (
+        Recursively => 1,
+        @_,
+    );
     my $groups = RT::Groups->new($self->CurrentUser);
     $groups->LimitToUserDefinedGroups;
     $groups->WithMember(
         PrincipalId => $self->Id,
-        Recursively => 1
+        Recursively => $args{'Recursively'},
     );
     return $groups;
 }
@@ -1753,7 +1734,7 @@ Returns a list of valid stylesheets take from preferences.
 sub Stylesheet {
     my $self = shift;
 
-    my $style = RT->Config->Get('WebDefaultStylesheet', $self->CurrentUser);
+    my $style = RT->Config->Get('WebDefaultStylesheet', $self);
 
     if (RT::Interface::Web->ComponentPathIsSafe($style)) {
         for my $root (RT::Interface::Web->StaticRoots) {
@@ -2260,8 +2241,8 @@ sub ToggleBookmark {
 Returns a list of hashrefs { id => <ticket_id>, subject => <ticket_subject> } )
 ordered by recently viewed first.
 
-If a ticket cannot be loaded (eg because it has been shredded) or is duplicated
-(eg because 2 tickets on the list have been merged), it is not returned and the
+If a ticket cannot be loaded (e.g. because it has been shredded) or is duplicated
+(e.g. because 2 tickets on the list have been merged), it is not returned and the
 user's RecentlyViewedTickets list is updated
 
 =cut
@@ -2346,6 +2327,132 @@ sub AddRecentlyViewedTicket {
     );
 }
 
+=head2 GetInitials
+
+Look in the user's RealName and Name (username) to find
+a first and last initial. Returns two or one uppercase
+characters.
+
+=cut
+
+sub GetInitials {
+    my $self = shift;
+
+    if ( $self->Id == RT->Nobody->Id ) {
+        return 'NB';
+    }
+
+    if ( $self->Id == RT->SystemUser->Id ) {
+        return 'SU';
+    }
+
+    my $first_initial;
+    my $last_initial;
+
+    my @names = split( /\s+/, ( $self->RealName || $self->Name || '' ) );
+    $first_initial = substr( $names[0],  0, 1 );
+    # Get the second character if the user name doesn't have space
+    $last_initial  = @names > 1 ? substr( $names[-1], 0, 1 ) : '';
+
+    return uc $first_initial . uc $last_initial;
+}
+
+=head2 GetColorClass
+
+Returns a string that can be used as a class with bootstrap to display
+a color for this user.
+
+=cut
+
+sub GetColor {
+    my $self = shift;
+
+    if ( ( $self->Id == RT->SystemUser->Id ) ||
+         ( $self->Id == RT->Nobody->Id) ) {
+        return 'system-blue';
+    }
+
+    # Bootstrap color list, minus black, white, and grays
+    my $color_list = [
+        "blue", "indigo", "purple", "pink", "red",
+        "orange", "yellow", "green", "teal", "cyan",
+    ];
+
+    my $color_index = reduce { $a + ord($b) } 0, split( '', $self->id );
+
+    return $color_list->[ $color_index % scalar(@$color_list) ];
+}
+
+sub SetImageAndContentType {
+    my $self = shift;
+    my ( $image, $content_type ) = @_;
+
+    $content_type = '' unless $image;
+
+    # Set ImageContentType here to make sure it's consistent
+    # with the image.
+    $RT::Handle->BeginTransaction;
+
+    if ( $content_type ne ( $self->ImageContentType // '' ) ) {
+        my ( $ok, $msg ) = $self->SetImageContentType($content_type);
+
+        unless ($ok) {
+            RT->Logger->error( "Unable to set ImageContentType for user " . $self->Id . " : $msg" );
+            $RT::Handle->Rollback;
+            return ( $ok, $msg );
+        }
+    }
+
+    if ( ( $self->Image // '' ) ne $image ) {
+        my ( $ok, $msg ) = $self->SetImage( MIME::Base64::encode_base64($image) );
+        if ($ok) {
+            $RT::Handle->Commit;
+            # We don't want to see "Image changed from [block of data] to [block of data]
+            return ( 1, $self->loc('Picture updated') );
+        }
+        else {
+            $RT::Handle->Rollback;
+            RT->Logger->error( "Unable to set Image for user " . $self->Id . " : $msg" );
+            return ( $ok, $msg );
+        }
+    }
+    else {
+        $RT::Handle->Commit;
+        return 1;
+    }
+
+}
+
+sub SetImage {
+    my $self            = shift;
+    my $encoded_content = shift;
+    if ( $encoded_content
+        && MIME::Base64::decoded_base64_length($encoded_content) > RT->Config->Get('MaxUserImageSize') )
+    {
+        return (
+            0,
+            $self->loc(
+                'Image too large, max is [_1]',
+                sprintf( '%.1fMB', RT->Config->Get('MaxUserImageSize') / 1024**2 )
+            )
+        );
+    }
+    return $self->_Set( Field => 'Image', Value => $encoded_content );
+}
+
+sub Image {
+    my $self = shift;
+    if ( my $image = $self->_Value('Image') ) {
+        return MIME::Base64::decode_base64($image);
+    }
+    return;
+}
+
+sub ImageSignature {
+    my $self = shift;
+    return Digest::SHA::sha1_hex($self->_Value('Image'));
+}
+
 =head2 Create PARAMHASH
 
 Create takes a hash of values and creates a row in the database:
@@ -2373,6 +2480,8 @@ Create takes a hash of values and creates a row in the database:
   varchar(16) 'Zip'.
   varchar(50) 'Country'.
   varchar(50) 'Timezone'.
+  varchar(80) 'ImageContentType'.
+  text 'Image'.
 
 =cut
 
@@ -2819,6 +2928,54 @@ Returns (1, 'Status message') on success and (0, 'Error Message') on failure.
 
 =cut
 
+=head2 SetImageAndContentType IMAGE, IMAGE CONTENT TYPE
+
+Properly encodes IMAGE and sets Image, and also sets
+ImageContentType to make sure it gets the correct
+corresponding value.
+
+=cut
+
+=head2 ImageContentType
+
+Returns the current value of ImageContentType.
+
+=cut
+
+=head2 SetImageContentType VALUE
+
+Set ImageContentType to VALUE.
+
+Returns (1, 'Status message') on success and (0, 'Error Message') on failure.
+(In the database, ImageContentType is stored as text.)
+
+=cut
+
+=head2 Image
+
+Returns the user's image. If it's base64 encoded, decodes it
+before returning it.
+
+=cut
+
+=head2 SetImage VALUE
+
+Set Image to VALUE.
+
+You probably want to call SetImageAndContentType
+instead of this method to make sure the image is encoded and the
+content type is set correctly.
+
+Returns (1, 'Status message') on success and (0, 'Error Message') on failure.
+(In the database, Image is stored as a longblob.)
+
+=cut
+
+=head2 ImageSignature
+
+Returns the user's image SHA-1 signature.
+
+=cut
 
 =head2 Creator
 
@@ -2910,6 +3067,10 @@ sub _CoreAccessible {
         {read => 1, write => 1, sql_type => 12, length => 50,  is_blob => 0,  is_numeric => 0,  type => 'varchar(50)', default => ''},
         SMIMECertificate =>
         {read => 1, write => 1, sql_type => -4, length => 0,  is_blob => 1,  is_numeric => 0,  type => 'text', default => ''},
+        ImageContentType =>
+        {read => 1, write => 1, sql_type => 12, length => 80,  is_blob => 0,  is_numeric => 0,  type => 'varchar(80)', default => ''},
+        Image =>
+        {read => 1, write => 1, sql_type => -4, length => 0,  is_blob => 1,  is_numeric => 0,  type => 'text', default => ''},
         Creator => 
         {read => 1, auto => 1, sql_type => 4, length => 11,  is_blob => 0,  is_numeric => 1,  type => 'int(11)', default => '0'},
         Created => 
@@ -3062,6 +3223,9 @@ sub BeforeWipeout {
 
 sub Serialize {
     my $self = shift;
+    my %args = @_;
+    $args{serializer}{_uid}{user}{ $self->Id } = $self->UID;
+
     return (
         Disabled => $self->PrincipalObj->Disabled,
         Principal => $self->PrincipalObj->UID,
@@ -3102,18 +3266,21 @@ sub PreInflate {
         return;
     }
 
-    # Create a principal first, so we know what ID to use
-    my $principal = RT::Principal->new( RT->SystemUser );
-    my ($id) = $principal->Create(
-        PrincipalType => 'User',
-        Disabled => $disabled,
-    );
+    # serialized data with --all has principals, in which case we don't need to create a new one.
+    my $principal_obj = $importer->LookupObj( $principal_uid );
+    if ( $principal_obj ) {
+        $data->{id} = $principal_obj->Id;
+    }
+    else {
 
-    # Now we have a principal id, set the id for the user record
-    $data->{id} = $id;
+        # Create a principal first, so we know what ID to use
+        my $id = $importer->NextPrincipalId( PrincipalType => 'User', Disabled => $disabled );
 
-    $importer->Resolve( $principal_uid => ref($principal), $id );
-    $data->{id} = $id;
+        # Now we have a principal id, set the id for the user record
+        $data->{id} = $id;
+
+        $importer->Resolve( $principal_uid => 'RT::Principal', $id );
+    }
 
     return $class->SUPER::PreInflate( $importer, $uid, $data );
 }
@@ -3123,6 +3290,19 @@ sub PostInflate {
     RT->InitSystemObjects if $self->Name eq "RT_System";
 }
 
+=head2
+
+Returns this user's dashboard subscriptions.
+
+=cut
+
+sub DashboardSubscriptions {
+    my $self          = shift;
+    my $subscriptions = RT::DashboardSubscriptions->new( $self->CurrentUser );
+    $subscriptions->Limit( FIELD => 'UserId', VALUE => $self->Id );
+    return $subscriptions;
+}
+
 RT::Base->_ImportOverlays();
 
 
